.webix_view {
  font-family: Arial;
  font-size: 13px;
  color: #555555;
  cursor: default;
  overflow: hidden;
  border: 0px solid #c8c8c8;
  background-color: #ffffff;
  white-space: normal;
  -webkit-appearance: none;
}
.webix_view.webix_form {
  background-color: #ffffff;
  /*.webix_view{
		background-color: @backColor;
	}*/
}
body {
  -webkit-tap-highlight-color: transparent !important;
}
textarea,
input,
select,
button,
.webix_inp_static {
  outline: none;
}
/*
	webix_layout_{type}
	known types are: line, clean, wide, space;
*/
.webix_layout_space {
  background-color: #ffffff;
}
.webix_layout_wide {
  background-color: #ffffff;
}
.webix_layout_line,
.webix_multiview,
.webix_layout_clean,
.webix_layout_accordion {
  background: transparent;
}
.webix_overlay {
  width: 100%;
  height: 100%;
  position: absolute;
  z-index: 10;
  text-align: center;
  padding-top: 10px;
}
.webix_view > .webix_disabled {
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
  background-color: #ddd;
  opacity: 0.4;
  filter: progid:DXImageTransform.Microsoft.Alpha(opacity=40);
  z-index: 1;
}
.webix_disabled_view {
  overflow: hidden !important;
}
body.webix_full_screen {
  margin: 0;
  padding: 0;
  overflow: hidden;
}
.webix_noselect,
.webix_noselect div {
  -moz-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.webix_selectable {
  -moz-user-select: text;
  -webkit-user-select: text;
  user-select: text;
}
.webix_template {
  height: 100%;
  padding: 5px;
  padding-left: 5px 2px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_clean {
  background: transparent;
}
.webix_clean .webix_template {
  padding: 0px;
}
.webix_section {
  padding-left: 30px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  background-color: transparent;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAUCAIAAADDbMD2AAAABnRSTlMA/wD/AP83WBt9AAAACXBIWXMAAA7EAAAOxAGVKw4bAAAAHElEQVR4nGP4//8/EwMDA158/vx5BmLUMTAwAADGhQiMQPqPwgAAAABJRU5ErkJggg==);
  background-repeat: repeat-x;
  background-position: 9px;
  color: #444;
  font-size: 10px;
  text-transform: uppercase;
  line-height: 36px;
}
.webix_section > .webix_template {
  padding: 0px 8px;
  background-color: #ffffff;
  display: inline;
}
.webix_layout_space > .webix_section > .webix_template {
  padding: 0px 8px;
  background-color: #ffffff;
}
.webix_layout_wide > .webix_section > .webix_template {
  padding: 0px 8px;
  background-color: #ffffff;
}
.webix_layout_line > .webix_section > .webix_template,
.webix_layout_clean > .webix_section > .webix_template {
  padding: 0px 8px;
  background-color: #ffffff;
}
.webix_header > div {
  padding-left: 10px;
  font-size: 13px;
  background: #ffffff;
  line-height: 34px;
  line-height: 36px;
  padding-top: 0;
  padding-bottom: 0;
}
.webix_header > div .webix_el_label,
.webix_header > div .webix_inp_label {
  font-size: 13px;
}
.webix_header > div .webix_el_button {
  color: #555555 !important;
}
.webix_header > div .webix_el_button input,
.webix_header > div .webix_el_toggle input {
  border: none;
}
.webix_spacer {
  background: transparent;
}
x\:ui {
  display: none;
}
.webix_resize_area {
  position: absolute;
  top: 0px;
  left: 0px;
  width: 100%;
  height: 100%;
}
.webix_resize_handle_x .webix_handle_content,
.webix_resize_handle_y .webix_handle_content {
  width: 100%;
  height: 100%;
  background: rgba(100, 100, 100, 0.1);
  border: 1px dotted #dadada;
}
.webix_resize_handle_x {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  cursor: e-resize;
  width: 1px;
  height: 100%;
  position: absolute;
  z-index: 2;
  top: 0px;
}
.webix_resize_handle_x .webix_handle_content {
  border-width: 0px 1px;
}
.webix_resize_origin_x {
  cursor: e-resize;
  width: 3px;
  height: 100%;
  position: absolute;
  z-index: 2;
  top: 0px;
}
.webix_resize_handle_y {
  cursor: n-resize;
  height: 1px;
  width: 100%;
  position: absolute;
  z-index: 2;
  left: 0px;
}
.webix_resize_handle_y .webix_handle_content {
  border-width: 1px 0px;
}
.webix_resize_origin_y {
  cursor: n-resize;
  height: 3px;
  width: 100%;
  position: absolute;
  z-index: 2;
  left: 0px;
}
.webix_resizer_vy {
  cursor: n-resize;
  margin-top: 0px !important;
  border: 0px !important;
  padding: 0px !important;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABcAAAADAQMAAABCowZuAAAABlBMVEUAAACkvtSA7tmIAAAAAXRSTlMAQObYZgAAAA9JREFUCB1jXMUABoxAGgAJaAFXPIkJqAAAAABJRU5ErkJggg==) no-repeat center center;
}
.webix_resizer_vx {
  cursor: e-resize;
  margin-left: 0px !important;
  border: 0px !important;
  padding: 0px !important;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAMAAAAXAQMAAAD0oWdxAAAABlBMVEUAAACkvtSA7tmIAAAAAXRSTlMAQObYZgAAAA5JREFUeF5jWMDAQDwGAKyuB4FpGQdzAAAAAElFTkSuQmCC) no-repeat center center;
}
.webix_resizer_y {
  cursor: n-resize;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABcAAAADAQMAAABCowZuAAAABlBMVEUAAACkvtSA7tmIAAAAAXRSTlMAQObYZgAAAA9JREFUCB1jXMUABoxAGgAJaAFXPIkJqAAAAABJRU5ErkJggg==) no-repeat center center;
  background-color: #ffffff;
}
.webix_resizer_x {
  cursor: e-resize;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAMAAAAXAQMAAAD0oWdxAAAABlBMVEUAAACkvtSA7tmIAAAAAXRSTlMAQObYZgAAAA5JREFUeF5jWMDAQDwGAKyuB4FpGQdzAAAAAElFTkSuQmCC) no-repeat center center;
  background-color: #ffffff;
}
.webix_accordionitem_body {
  position: relative;
}
.webix_accordionitem_header {
  border-bottom: 1px solid #c8c8c8;
  position: relative;
  z-index: 2;
  font-size: 13px;
  background: #ffffff;
  line-height: 34px;
  cursor: pointer;
  overflow: hidden;
}
.webix_accordionitem_header .webix_el_label,
.webix_accordionitem_header .webix_inp_label {
  font-size: 13px;
}
.webix_accordionitem_header .webix_el_button {
  color: #555555 !important;
}
.webix_accordionitem_header .webix_el_button input,
.webix_accordionitem_header .webix_el_toggle input {
  border: none;
}
.webix_accordionitem_label {
  height: 100%;
  padding-left: 10px;
}
.webix_accordionitem_button {
  float: right;
  position: relative;
  height: 11px;
  width: 11px;
  margin: 15px 15px;
}
/*
.webix_accordionitem.vertical > .webix_accordionitem_header .webix_accordionitem_button{
	.accIconUp;
}
.webix_accordionitem.vertical.collapsed > .webix_accordionitem_header .webix_accordionitem_button{
	.accIconDown;
}

.webix_accordionitem.horizontal  > .webix_accordionitem_header .webix_accordionitem_button{
	.accIconLeft;
}
.webix_accordionitem.horizontal:last-child  > .webix_accordionitem_header .webix_accordionitem_button{
	.accIconRight;
}
.webix_accordionitem.horizontal.collapsed:last-child  > .webix_accordionitem_header .webix_accordionitem_button{
	.accIconDown;
}
.webix_accordionitem.horizontal.collapsed  > .webix_accordionitem_header{
	.webix_accordionitem_button{
		.accIconUp;
	}
}*/
.webix_carousel {
  position: relative;
}
.webix_nav_panel {
  bottom: 15px;
  height: auto;
  line-height: 8px;
  overflow: hidden;
  position: absolute;
  text-align: center;
}
.webix_nav_item {
  display: inline-block;
  height: 8px;
  padding: 6px 5px 6px 4px;
  width: 8px;
  cursor: pointer;
}
.webix_nav_item div {
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  border-radius: 50%;
  display: block;
  height: 8px;
  width: 8px;
}
.webix_nav_inactive div {
  border: 1px solid rgba(0, 0, 0, 0.15);
  filter: alpha(opacity=60);
  opacity: 0.6;
  background: #ffffff;
}
.webix_nav_active div {
  border: 1px solid rgba(0, 0, 0, 0.1);
  background: #ffffff;
}
.webix_nav_button_prev,
.webix_nav_button_next {
  cursor: pointer;
  display: block;
  height: 24px;
  position: absolute;
  width: 24px;
}
.webix_nav_button_prev .webix_nav_button_inner,
.webix_nav_button_next .webix_nav_button_inner {
  height: 100%;
  width: 100%;
}
.webix_nav_button_prev .webix_nav_button_inner {
  opacity: 0.8;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAMAAADXqc3KAAAAkFBMVEX///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////9oY44IAAAAL3RSTlMA5gMYAUkXBucVVEocD8fDs9UOpxPMrJ/d0Zo9Vtuc2KHTqc8RBa7KtsUMwNoZ5NXTkv8AAAB+SURBVHhepZFFEsNADARnwY6zhiAzM/z/d9ED+mYd1aUakDL3g3GZbI9EhnHagl5ICJqhcgKTWp0+gMVYfgoag678CMTfH8UZuJpXikuyu5LWmGNjF1sMuMvl95j8YK6OWMnprMsVu7pZ8jt29XgqcLuvkFo8yjEoVBYEvuUf4K9fs/aQs0YAAAAASUVORK5CYII=);
}
.webix_nav_button_next .webix_nav_button_inner {
  opacity: 0.8;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAMAAADXqc3KAAAAllBMVEX////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////MC6PrAAAAMXRSTlMA5gMBGA9JFecGSlXMrBPRwxfVn8ezp5oc3Fc8nBvboRbXqdOuBRHPtsoMxVTAGdrkjQ/x3gAAAHlJREFUeF6l0TUSxUAAAlDW4v7d3ZX7Xy4XoAvtKxgGRIYiJoIhpYA6HAC5bzS0CGMJkxShUMDSoqoVcGoRdwo4cvj+FHDmMF8o4BJYKVg7bLYCdhb7g+g4WsQnseN8wfUmdtxThAcFeDxfVPD2n6FHGQ0JskTBP+sBkWlj0yhGTYEAAAAASUVORK5CYII=);
}
.webix_nav_panel_corner {
  right: 73px;
}
.webix_nav_button_corner.webix_nav_button_prev {
  bottom: 13px;
  right: 37px;
}
.webix_nav_button_corner.webix_nav_button_prev .webix_nav_button_inner:hover {
  opacity: 1;
}
.webix_nav_button_corner.webix_nav_button_next {
  bottom: 13px;
  right: 7px;
}
.webix_nav_button_corner.webix_nav_button_next .webix_nav_button_inner:hover {
  opacity: 1;
}
.webix_nav_panel_side {
  margin: 0 auto;
  left: 0;
  width: 100%;
}
.webix_nav_button_side {
  height: 34px;
  width: 21px;
  top: 50%;
  margin-top: -17px;
}
.webix_nav_button_side.webix_nav_button_next {
  left: auto;
  right: 15px;
}
.webix_nav_button_side.webix_nav_button_next .webix_nav_button_inner {
  opacity: 0.8;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABUAAAAiCAMAAACHtmKxAAAAY1BMVEX///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////+Dm4mgAAAAIHRSTlMAeoGDeXuCgH94fHaE+Xdn/OXaWa6xVBPgqn4SpPffYIKC8HcAAABrSURBVHherchHDoAgEADAVbBh7135/yst2YOQjWJ0jgNtFRcl6Gq5C/XNJNW5PCXqppLsCDswanbf3KhdbOtL29jOqxZqe2RzXPZjWpiucdqP6bxO75qCygbTh6uOSoiphP7IATTjNC+rnhuwqx1LOFJshAAAAABJRU5ErkJggg==);
}
.webix_nav_button_side.webix_nav_button_next .webix_nav_button_inner:hover {
  opacity: 1;
}
.webix_nav_button_side.webix_nav_button_prev {
  left: 15px;
  right: auto;
}
.webix_nav_button_side.webix_nav_button_prev .webix_nav_button_inner {
  opacity: 0.8;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABUAAAAiCAMAAACHtmKxAAAARVBMVEX///////////////////////////////////////////////////////////////////////////////////////////+QFj7cAAAAFnRSTlMADxBTWV9ndXx9g4SlqKrZ29zh8vb3FGTUtQAAAEZJREFUeF7lyDcSgDAMBMBzIsqBYP3/qVBQaa6kYdhyYYXWi7c56S2z1JOlbiw1sZx/mFieHfF+rx/vSLuC9QHWAmvYu7gLhysVAAFZzegAAAAASUVORK5CYII=);
}
.webix_nav_button_side.webix_nav_button_prev .webix_nav_button_inner:hover {
  opacity: 1;
}
.webix_carousel > .webix_scroll_x,
.webix_carousel > .webix_scroll_y {
  background-color: rgba(0, 0, 0, 0);
}
.webix_dark .webix_nav_inactive div {
  background-color: #95a5a6;
}
.webix_dark .webix_nav_active div {
  background-color: #7f8c8d;
}
.webix_dark .webix_nav_button_prev .webix_nav_button_inner {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH3gcdCSIURgotfwAAASxJREFUSMfNlbErhlEUh5/vJZOSQSijshgsFiklhdj0lcHw5SP7uX+A8we4d1c+g2RgsIjIxmCxGCzKRO9bMjCSWE5WpXPrO9MZbs9T5577u7XNrTgPtIBBfKsEmkUmOMZsFZngv5KCzNW2gmsbbT2H4AZY0CAVcOUtuAXmNMi7xtQF7HgK7oBZDfKmMXUAB8Cil+AemNEgrwbfB5a8LvnB4C8aU83Gsuy1RY/AtAYpDb4NNDzXtKFBnqyvA+ve72BXYxqy/shyy1UwDFxqTP0a5BvYAPa8X/KISfo0yBewChx6R8UocKEx9ZpkBTj2zqIx4Fxj6tEgn7aqZ95RMQ6cakzdGuTDxuUedhPAicY0AEz+dbjzn3E9ZX9ue3w4ZUZ+VQBrQJUB/gw0fwC/UlVpnH2f9AAAAABJRU5ErkJggg==);
}
.webix_dark .webix_nav_button_next .webix_nav_button_inner {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH3gcdCSENCUzWfAAAAS1JREFUSMfN1TFLXEEUhuFnr8FKCBaGiK2FRQobG7GSgBG2E8IWFmE3wX7uD3B+QOb2QpaAiMWmsAkJBtMEizQ2FmmCXcIuhBRpDZI0g7XCXNhTD+8L53znTGf/ddrGEIvK1hiDqiW4zBxWLcFvJZWWayoEz3Mbz9sSfIl1mKCLr20I3sTUzMY6/MEzXJQWdHEcUzOTJVu4LD3kHRxlyW88xbfSKerldnViHX5lyffSMX2BgywZYxNXpffgVY6uWIcfWVpUMMQIYmqW8Lak4BB7sQ7/Ymoe4QzLpQQj9GMdbmJqFvAZK6WGfILdDJ/HJzwpFdOP6MU6/I2peYhTrJZctH6sw3VMzRw+YK30qdiIqXmM91i/b+Qe3OHNu6n/cMYt8icVXmLSAvwnBv8B+EFU7qlZ1xIAAAAASUVORK5CYII=);
}
.webix_dark .webix_nav_button_side.webix_nav_button_prev .webix_nav_button_inner {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABUAAAAiCAYAAACwaJKDAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH3gcdCSI77dsQJgAAARxJREFUSMet1jFqAkEUxvH/rkIqLVN5ES2CjScQG6tUESx3SWOMLKgggt7BC6SxsnIr9w4ewAsEEis3RTBE3N3ZmfemHB4/HsPMm89L0xTJilbrLrAAGsAWeKkKwTEw/bfVAy6ea6cZ4HV9+8ogwMm6UwMI8Owrg5MoDDa+MjgF8LXBUqgtaERdwELUFcxFJWAmKgXvUA3wBtUC/1BNEKBCra4KXjt9MNScbadYJd7t9nGSVIGnnJpOnCRf7VbzYNMpURi8A7OCumW0Wr9aodrw7T39hedS+P5FhcFYCme/fSGcP6UEcPE8dYTNk98BLvdHWcLlf1ML2CVMzIC3gpK+U5YywEdJQMuDP50CmuGMt55C6B0AI+AR+ACGPw26r6m12WOpAAAAAElFTkSuQmCC);
}
.webix_dark .webix_nav_button_side.webix_nav_button_next .webix_nav_button_inner {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABUAAAAiCAYAAACwaJKDAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH3gcdCSE1IU5u4gAAAW1JREFUSMet1rtOwzAUgOG/5jbBwsQD8BAwIAa2TggegjmRgELbuFeo1GRlQEJMMDN264CUiYdgg0dolzIkFUEk9nHSbLGtT76cc+xaMA53gUegDnwCgfa9Vyp8CngCToFNYB940WF0WRWt57SPqsAK+C7oG+kwuiqLdg3992Xgtelk8jGN4w3gqGDMyTSOZ8eHB+8uM0X7XhMYGMbd6TC6dkIzcH8VsMr+aN9rCeCGEyqEhzZY5TWmcM8C3zihKdy2wIMiWJmWURZWtk1P4a4FvnVCUziwwP0srKQBLYSbALXFYuGU1zqMNBAYhrRUiSI0s/RvKcdZNoChcQt8Tz5TKSg/fQdQFqdJcJvAXha0Z1QCDixgW577drCbBxZXKRkYyOtpkm6lwf+VPwH7VcC/d5Qd7EjA39s0KQQ2UIvvfbZ3zoEHU2Rp3+u4vlDGqwSX6N4qwSX6ltMelAUB1oELYA6cAV/poTxXeZ/+AOFqn1e/Gh7yAAAAAElFTkSuQmCC);
}
.webix_list_item {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  padding: 2px 10px;
  line-height: 27px;
  cursor: pointer;
  border-bottom: 1px solid transparent;
  text-align: left;
}
.webix_list_item.webix_selected {
  color: #ffffff;
  background: #fea223;
}
.webix_list .webix_list_item.webix_selected {
  border-bottom: 1px solid #fe990f;
  border-top: 1px solid #fe990f;
  padding: 2px 10px;
}
.webix_list_item.webix_invalid {
  background-color: #ffeeee;
}
.webix_group {
  position: relative;
}
.webix_group_back,
.webix_group_back.webix_selected {
  position: relative;
  background: #c8c8c8;
  font-size: 15px;
  color: #555555;
}
.webix_arrow_icon {
  position: absolute;
  top: 50%;
  bottom: 50%;
  margin-top: -12px;
  right: 15px;
  width: 9px;
  height: 22px;
  line-height: 22px;
  color: #555555;
  font-size: 18px;
  font-family: FontAwesome;
}
.webix_arrow_icon:before {
  content: '\f105';
}
.webix_group_back {
  padding-left: 29px;
}
.webix_group_back .webix_arrow_icon {
  left: 11px;
}
.webix_group_back .webix_arrow_icon:before {
  content: '\f104';
}
.dhx_pagelist {
  position: relative;
}
.webix_list_count {
  float: right;
  width: 25px;
  font-size: 14px;
  text-align: center;
  margin-right: 45px;
  box-shadow: 0 1px 0 #000000;
  text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
}
.webix_unit_header {
  padding: 0 10px;
  line-height: 19px;
  text-align: left;
  background-color: #c8c8c8;
}
.webix_list-x .webix_list_item {
  display: inline-block;
  vertical-align: top;
  border-right: 1px solid transparent;
  border-bottom: none;
}
.webix_list-x .webix_list_item.webix_selected {
  border-left: 1px solid #fe990f;
  border-right: 1px solid #fe990f;
  padding-left: 9px;
}
.webix_list-x .webix_scroll_cont {
  display: inline;
}
.webix_view.webix_list-x {
  white-space: nowrap;
}
/* Style for disabled items */
.webix_list_item.webix_disabled {
  color: #8b949e;
}
.webix_list_item.webix_disabled .webix_submenu_icon {
  visibility: hidden;
}
/*button of pager*/
.webix_pager {
  padding: 2px 0;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  background-color: transparent;
}
.webix_pager_item,
.webix_pager_item_selected {
  padding: 0 6px;
  text-align: center;
  height: 100%;
  width: 32px;
  border: 1px solid #c8c8c8;
  margin: 0 2px;
  cursor: pointer;
  background-color: white;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  font-family: Arial;
  font-size: 13px;
}
/*selected  button of pager*/
.webix_pager_item_selected {
  cursor: default;
  background-color: #fea223;
  border: 1px solid #fe990f;
}
.webix_animation .webix_ss_header {
  position: relative;
  z-index: 10;
}
.webix_animation .webix_ss_footer,
.webix_animation .webix_vscroll_x {
  position: absolute;
  bottom: 0px;
  z-index: 10;
}
/*helper for allowing selection*/
.webix_allow_selection {
  -moz-user-select: text;
  -webkit-user-select: text;
  user-select: text;
}
/*default item in dataview*/
.webix_dataview_item {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  padding: 2px 10px;
  line-height: 27px;
  cursor: pointer;
  border-bottom: 1px solid transparent;
  text-align: left;
  border-right: 1px solid transparent;
}
/*default item in selected state*/
.webix_dataview_item.webix_selected {
  color: #ffffff;
  background: #fea223;
  border-bottom: 1px solid #fe990f;
  border-right: 1px solid #fe990f;
}
/*chart container*/
.webix_chart {
  position: relative;
  font-family: Arial;
  font-size: 13px;
  color: #555555;
  overflow: hidden;
  z-index: 1;
}
.webix_chart canvas {
  position: absolute;
}
/*labels*/
.webix_canvas_text {
  position: absolute;
  text-align: center;
  overflow: hidden;
  white-space: nowrap;
  font-size: 12px;
  z-index: 100;
}
/*map*/
.webix_map_img {
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0px;
  left: 0px;
  border: 0px;
  filter: progid:DXImageTransform.Microsoft.Alpha(opacity=0);
  opacity: 0;
}
/*scales*/
.webix_axis_item_y {
  position: absolute;
  height: 18px;
  line-height: 18px;
  /*line-height:10px;*/
  margin-top: -4px;
  text-align: right;
}
.webix_axis_item_x {
  padding-top: 2px;
}
.webix_axis_title_x {
  text-align: center;
  font-size: 13px;
}
.webix_axis_title_y {
  text-align: center;
  font-family: Verdana;
  font-size: 13px;
  /*safari*/
  -webkit-transform: rotate(-90deg);
  /*firefox*/
  -moz-transform: rotate(-90deg);
  /*opera*/
  -o-transform: rotate(-90deg);
  /*IE9*/
  -ms-transform: rotate(-90deg);
  transform: rotate(-90deg);
  padding-left: 3px;
}
.webix_ie_filter {
  /*IE8*/
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3);
}
/*legend block*/
.webix_chart_legend {
  position: absolute;
  z-index: 1000;
}
.webix_chart_legend_item {
  height: 18px;
  line-height: 18px;
  padding: 2px;
}
.webix_chart_legend_item.hidden {
  color: #d4d4d4;
}
.webix_axis_item_y.webix_radar {
  color: #555;
  font-size: 11px;
  padding-right: 3px;
  height: 13px;
  line-height: 13px;
  margin-top: 0px;
}
.webix_canvas_text.webix_axis_radar_title {
  margin-top: 0px;
  padding-top: 0px;
  color: #888888;
  font-size: 12px;
}
.webix_axis_item_y,
.webix_axis_item_x {
  color: #888888;
}
.webix_vscroll_x {
  height: 0px;
  width: 100%;
  overflow-y: hidden;
  overflow-x: scroll;
}
.webix_vscroll_y {
  width: 0px;
  height: 100%;
  overflow-x: hidden;
  overflow-y: scroll;
}
.webix_vscroll_body {
  width: 16px;
  height: 16px;
}
.webix_scroll_x {
  width: 50px;
  height: 4px !important;
  left: 1px;
  bottom: 3px;
  background-color: silver;
  background: rgba(0, 0, 0, 0.4);
  position: absolute;
  border-radius: 4px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_scroll_y {
  width: 4px !important;
  height: 50px;
  top: 1px;
  right: 3px;
  background-color: silver;
  background: rgba(0, 0, 0, 0.4);
  position: absolute;
  border-radius: 4px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_c_scroll_y {
  position: absolute;
  z-index: 1;
  width: 10px;
  right: 0px;
}
.webix_c_scroll_y > div {
  -moz-transition: width 0.3s 0.2s, margin 0.3s 0.2s;
  -webkit-transition: width 0.3s 0.2s, margin 0.3s 0.2s;
  -o-transition: width 0.3s 0.2s, margin 0.3s 0.2s;
  -ms-transition: width 0.3s 0.2s, margin 0.3s 0.2s;
  width: 4px;
  height: 100%;
  background-color: silver;
  background: rgba(0, 0, 0, 0.4);
  border-radius: 4px;
  margin: 0px 3px;
}
.webix_c_scroll_y:hover > div,
.webix_c_scroll_y.webix_scroll_active div {
  width: 10px;
  margin: 0px;
}
.webix_c_scroll_x {
  position: absolute;
  z-index: 1;
  height: 10px;
  bottom: 0px;
}
.webix_c_scroll_x > div {
  -moz-transition: height 0.3s 0.2s, margin 0.3s 0.2s;
  -webkit-transition: height 0.3s 0.2s, margin 0.3s 0.2s;
  -o-transition: height 0.3s 0.2s, margin 0.3s 0.2s;
  -ms-transition: height 0.3s 0.2s, margin 0.3s 0.2s;
  height: 4px;
  width: 100%;
  background-color: silver;
  background: rgba(0, 0, 0, 0.4);
  border-radius: 4px;
  margin: 3px 0px;
}
.webix_c_scroll_x:hover > div,
.webix_c_scroll_x.webix_scroll_active div {
  height: 10px;
  margin: 0px;
}
.webix_scroll_cont {
  width: 100%;
  height: auto;
  overflow: hidden;
  clear: both;
}
.webix_dt_editor {
  position: absolute;
  z-index: 2;
  overflow: visible;
  background: white;
}
.webix_dt_editor input,
.webix_dt_editor select {
  width: 100%;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  /* to look perfect in IE it must be 1/9/0/9 */
  padding: 1px 8px 0px 9px;
  margin: 0px;
  border: 1px solid #ffd700;
  height: 100%;
  font-family: Arial;
  font-size: 13px;
  color: #555555;
}
.webix_dt_editor input[type="checkbox"] {
  margin: 6px 8px 4px 14px;
  height: auto;
  width: auto;
}
.webix_dt_editor select {
  padding-right: 0px;
  padding-left: 5px;
}
.webix_clipbuffer {
  width: 1px;
  height: 1px;
  left: 3px;
  top: 3px;
  position: fixed;
  filter: alpha(opacity=0);
  opacity: 0;
}
.webix_message_area {
  position: fixed;
  right: 5px;
  width: 250px;
  z-index: 1000;
}
.webix_info {
  min-width: 120px;
  padding: 4px 4px 4px 20px;
  font-family: Tahoma, Arial;
  z-index: 10000;
  overflow: hidden;
  margin: 5px;
  margin-bottom: 10px;
  -webkit-transition: all .5s ease;
  -moz-transition: all .5s ease;
  -o-transition: all .5s ease;
  transition: all .5s ease;
}
.webix_no_transition {
  -webkit-transition: none;
  -moz-transition: none;
  transition: none;
}
.webix_info.hidden {
  height: 0px;
  min-height: 0px;
  padding-top: 0px;
  padding-bottom: 0px;
  border-width: 0px;
  margin-top: 0px;
  margin-bottom: 0px;
  overflow: hidden;
}
.webix_modal_box {
  overflow: hidden;
  display: inline-block;
  min-width: 250px;
  width: 250px;
  text-align: center;
  position: fixed;
  background-color: #fff;
  box-shadow: 0px 3px 6px #c8c8c8;
  font-family: Arial;
  z-index: 20000;
  border-radius: 0px;
  border: 1px solid #ffffff;
}
.webix_popup_title {
  border-top-left-radius: -1px;
  border-top-right-radius: -1px;
  border-width: 0px;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAoCAMAAAAIaGBFAAAAhFBMVEVwcHBubm5sbGxqampoaGhmZmZlZWVjY2NhYWFfX19dXV1bW1taWlpYWFhWVlZUVFRSUlJRUVFPT09NTU1LS0tJSUlHR0dGRkZERERCQkJAQEA+Pj49PT09PT0+Pj5AQEBBQUFDQ0NERERGRkZHR0dJSUlKSkpMTExMTEw5OTk5OTk5OTkny8YEAAAAQklEQVQImQXBCRJCAAAAwKVSQqdyjSPXNP7/QLsIhA6OTiJnF7GrRCpzc/fw9PKW+/gqlCq1RqvTG/yMJrPF6m/bAVEhAxxnHG0oAAAAAElFTkSuQmCC);
  background-image: -webkit-linear-gradient(top, #707070 1%, #3d3d3d 70%, #4c4c4c 97%, #393939 97%);
  background-image: -moz-linear-gradient(top, #707070 1%, #3d3d3d 70%, #4c4c4c 97%, #393939 97%);
}
.webix_info,
.webix_popup_button,
.webix_button {
  cursor: pointer;
}
.webix_popup_text {
  overflow: hidden;
}
.webix_popup_controls {
  border-radius: 6px;
  padding: 5px 10px 10px;
}
.webix_popup_button,
.webix_button {
  height: 24px;
  line-height: 24px;
  display: inline-block;
  margin: 0 5px;
  border-radius: 0px;
}
.webix_popup_button div {
  border-radius: 0px;
}
.webix_popup_button {
  min-width: 100px;
}
div.webix_modal_cover {
  background-color: #000;
  cursor: default;
  filter: progid:DXImageTransform.Microsoft.Alpha(opacity=10);
  opacity: 0.1;
  position: fixed;
  z-index: 19999;
  left: 0px;
  top: 0px;
  width: 100%;
  height: 100%;
  border: none;
  zoom: 1;
}
.webix_info img,
.webix_modal_box img {
  float: left;
  margin-right: 20px;
}
.webix_alert_error .webix_popup_title,
.webix_confirm_error .webix_popup_title {
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAsCAIAAAArRUU2AAAATklEQVR4nIWLuw2AMBBDjVuQiBT2oWbRDATrnB0KQOJoqPzRe3BrHI6dcBASYREKovtK6/6DsDOX+stN+3H1YX9ciRgnYq5EWYhS2dftBIuLT4JyIrPCAAAAAElFTkSuQmCC);
}
.webix_alert_error,
.webix_confirm_error {
  border: 1px solid #ff0000;
}
/*Skin section*/
.webix_button,
.webix_popup_button {
  border: 1px solid #c8c8c8;
}
.webix_button input,
.webix_popup_button div {
  font-size: 13px;
  background: #3389ff;
  color: #ffffff;
  font-size: 15px !important;
  border: 1px solid #3389ff !important;
  height: 24px;
  line-height: 24px;
}
.webix_popup_button.confirm div {
  background: #006bff;
  border: 1px solid #006bff;
  font-size: 15px !important;
  text-shadow: none !important;
  color: #ffffff !important;
  border-color: #006bff !important;
}
.webix_popup_title {
  color: #fff;
  text-shadow: 1px 1px #000;
  height: 40px;
  line-height: 40px;
  font-size: 20px;
}
.webix_popup_text {
  margin: 0 0 5px 0;
  padding-top: 25px;
  font-size: 13px;
  color: #555555;
  min-height: 60px;
}
.webix_info,
.webix_error {
  font-size: 13px;
  color: #555555;
  box-shadow: 0px 0px 10px #888;
  padding: 0px;
  background-color: #FFF;
  border-radius: 3px;
  border: 1px solid #ffffff;
}
.webix_info div {
  padding: 5px 10px 5px 10px;
  background-color: #fff;
  border-radius: 3px;
  border: 1px solid #B8B8B8;
}
.webix_error {
  background-color: #d81b1b;
  border: 1px solid #ff3c3c;
  box-shadow: 0px 0px 10px #000;
}
.webix_error div {
  background-color: #d81b1b;
  border: 1px solid #940000;
  color: #FFF;
}
.webix_drag_zone {
  position: absolute;
  box-shadow: 1px 1px 5px #c8c8c8;
  background-color: white;
  font-family: Arial;
  font-size: 13px;
  color: #555555;
}
.webix_drag_zone .borderless {
  padding: 2px 20px 2px 2px;
}
.webix_drag_over,
.webix_drop_zone {
  background-color: #ffffaa;
}
.webix_transparent {
  opacity: 0;
}
.webix_column {
  position: absolute;
  top: 0px;
}
.webix_cell {
  overflow: hidden;
  line-height: 31px;
  white-space: nowrap;
}
.webix_hcell {
  width: 100%;
  overflow: hidden;
}
.webix_ss_body {
  overflow: hidden;
  position: relative;
}
.webix_hs_left,
.webix_hs_center,
.webix_hs_right,
.webix_ss_center,
.webix_ss_right,
.webix_ss_left {
  overflow: hidden;
  float: left;
}
.webix_ss_center,
.webix_ss_right {
  position: relative;
}
.webix_ss_header table,
.webix_ss_footer table {
  table-layout: fixed;
}
.webix_ss_center_scroll {
  height: 100%;
  position: relative;
  overflow: hidden;
}
.webix_ss_hscroll {
  bottom: 0px;
}
.webix_ss_vscroll {
  position: absolute;
  top: 0px;
  right: 0px;
  z-index: 2;
}
.webix_ss_vscroll_footer {
  position: absolute;
  bottom: 0px;
  right: 0px;
  border-left: 1px solid #ffffff;
  border-top: 1px solid #c8c8c8;
  z-index: 1;
}
.webix_ss_vscroll_header {
  position: absolute;
  top: 0px;
  right: 0px;
  border-left: 1px solid #ffffff;
  border-bottom: 1px solid #c8c8c8;
  z-index: 1;
}
.webix_dtable {
  position: relative;
  cursor: default;
}
.webix_ss_footer,
.webix_ss_header {
  clear: both;
  overflow: hidden;
}
.webix_table_cell,
.webix_view.webix_table_cell,
.webix_block_selection,
.webix_ss_header td,
.webix_ss_footer td,
.webix_hcell,
.webix_cell {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_block_selection {
  position: absolute;
}
.webix_ss_sort_asc,
.webix_ss_sort_desc {
  position: absolute;
  right: 3px;
}
.webix_hcell.webix_ss_filter {
  padding: 2px 5px 2px 5px;
}
.webix_ss_filter select,
.webix_ss_filter input {
  width: 100%;
  font-size: inherit;
  color: #555555 !important;
  height: 32px;
  margin-top: -2px;
  padding: 0 3px;
  vertical-align: top;
  border: 1px solid #c8c8c8;
  line-height: 26px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  font-family: Arial;
}
.webix_richfilter {
  margin-top: 1px;
}
.webix_ss_filter select {
  padding: 3px;
}
/*headers and footers*/
.webix_ss_header,
.webix_ss_header TD,
.webix_ss_vscroll_header,
.webix_dd_drag_column {
  font-size: 15px;
  color: #555555;
  background: #c8c8c8;
}
.webix_ss_footer TD,
.webix_ss_vscroll_footer {
  background: white;
}
/*content in header and footer*/
.webix_hcell {
  padding: 0px 10px 0px 10px;
  text-align: left;
}
/*borders in header and footer*/
.webix_ss_header td {
  border-right: 1px solid #ffffff;
  border-bottom: 1px solid #ffffff;
  border-right: 1px dashed #ffffff;
  border-top: 1px dashed #ffffff;
  border-bottom: none;
}
.webix_ss_footer td {
  border-right: 1px solid transparent;
  border-top: 1px solid #ffffff;
}
/*remove rightmost borders*/
.webix_hs_right td.webix_last,
.webix_hs_center td.webix_last {
  border-right-width: 0px;
}
/*right inner border*/
.webix_column.webix_last > div {
  border-right-width: 0px;
}
/*borders between split areas*/
.webix_ss_right .webix_column.webix_first > div,
.webix_hs_right td.webix_first {
  border-left: 1px solid #c8c8c8;
}
.webix_ss_left .webix_column.webix_last > div {
  border-right: 1px solid #c8c8c8;
}
/*normal data cell of the table*/
.webix_column > div,
.webix_table_cell {
  border-right: 1px solid transparent;
  border-bottom: 1px solid transparent;
  padding: 0 10px;
}
.webix_column {
  text-align: left;
}
/*alter styles for even and odd rows*/
.webix_column > div:nth-child(even) {
  background-color: #ebebeb;
}
/*selection*/
.webix_column > div.webix_cell_select,
.webix_column > div.webix_column_select,
.webix_column > div.webix_row_select {
  color: #ffffff;
  background: #fea223;
}
/*extra borders, for selection in cell mode*/
.webix_column > div.webix_cell_select {
  border-bottom: 1px solid #fe990f;
  border-top: 1px solid #fe990f;
  border-left: 1px solid #fe990f;
  border-right: 1px solid #fe990f;
  padding-top: 0px;
  padding-left: 9px;
}
.webix_ss_right .webix_column.webix_first > div.webix_cell_select {
  padding-left: 10px;
}
/*extra borders, for selection in row mode*/
.webix_column > div.webix_row_select {
  border-bottom: 1px solid #fe990f;
  border-top: 1px solid #fe990f;
  padding-top: 0px;
}
/*extra borders for selection in column mode*/
.webix_column > div.webix_column_select {
  border-left: 1px solid #fe990f;
  border-right: 1px solid #fe990f;
  padding-left: 9px;
}
/*header selection in column mode*/
.webix_sel_hcell,
.webix_dd_over_column {
  background-color: #c9eaf5;
}
.webix_block_selection {
  background: rgba(0, 0, 0, 0.1);
  border: 2px solid #fe990f;
}
.webix_dd_drag {
  white-space: nowrap;
  overflow: hidden;
  border-left: 1px solid transparent;
  height: 34px;
}
.webix_dd_drag > div {
  display: inline-block;
  vertical-align: top;
  background: white;
  border-top: 1px solid transparent;
  border-right: 1px solid transparent;
  border-bottom: 1px solid transparent;
  padding: 5px 10px;
  height: 34px;
  line-height: 26px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_dd_drag_column {
  padding: 5px 10px 5px 10px;
}
.webix_column > .webix_drag_over.webix_cell {
  background-color: #ffffaa;
}
.webix_ss_header th,
.webix_ss_header td,
.webix_ss_header table {
  padding: 0px;
  margin: 0px;
}
.webix_cell.webix_invalid {
  background-color: #ffeeee;
}
.webix_column > .webix_cell.webix_invalid:nth-child(even) {
  background-color: #ffeeee;
}
.webix_invalid_cell {
  position: relative;
}
.webix_invalid_cell:after {
  content: "";
  position: absolute;
  top: 0px;
  right: 0px;
  width: 0px;
  height: 1px;
  border-top: 8px solid #f44;
  border-left: 8px solid transparent;
}
.webix_dtable_colrow {
  position: absolute;
  left: 0px;
  top: 0px;
  background-color: white;
  width: 100%;
  padding-right: 28px;
  padding-left: 10px;
  padding-top: 1px;
  border-bottom: 1px solid transparent;
}
.number .webix_cell {
  text-align: right;
}
.webix_rotate {
  transform: rotate(-90deg);
  -webkit-transform: rotate(-90deg);
  line-height: normal;
}
.webix_span_layer {
  background: transparent;
  position: absolute;
  left: 0px;
  top: 0px;
  height: 0px;
  width: 0px;
  overflow: visible;
}
.webix_dtable_span {
  position: absolute;
  background: #fff;
}
.webix_dtable_span.webix_selected {
  color: #ffffff;
  background: #fea223;
}
.webix_hcell span.webix_input_icon {
  background-color: #ffffff;
}
.webix_window {
  position: absolute;
  box-shadow: 1px 3px 4px #c8c8c8;
}
.webix_win_body {
  overflow: hidden;
}
.webix_window,
.webix_win_content,
.webix_win_body,
.webix_win_body > .webix_view {
  border-radius: 0px;
}
.webix_win_body > .webix_view .webix_cal_month {
  border-radius: 0px;
}
.webix_win_head {
  border-bottom: 1px solid silver;
  border-radius-top: 5px;
}
.webix_win_head > .webix_view > .webix_template {
  font-size: 13px;
  background: #ffffff;
  padding: 0px;
  text-align: center;
  line-height: 36px;
}
.webix_win_head > .webix_view > .webix_template .webix_el_label,
.webix_win_head > .webix_view > .webix_template .webix_inp_label {
  font-size: 13px;
}
.webix_win_head > .webix_view > .webix_template .webix_el_button {
  color: #555555 !important;
}
.webix_win_head > .webix_view > .webix_template .webix_el_button input,
.webix_win_head > .webix_view > .webix_template .webix_el_toggle input {
  border: none;
}
/*----------------------------*/
/* DO NOT CHANGE STYLES BELOW */
/*----------------------------*/
.webix_win_content {
  height: auto;
  width: auto;
  overflow: hidden;
}
.webix_modal {
  width: 100%;
  height: 100%;
  position: fixed;
  top: 0;
  left: 0;
  background-color: black;
  filter: progid:DXImageTransform.Microsoft.Alpha(opacity=20);
  opacity: 0.2;
}
.webix_point_top,
.webix_point_right,
.webix_point_bottom,
.webix_point_left {
  position: absolute;
}
.webix_point_top,
.webix_point_bottom {
  width: 13px;
  height: 7px;
}
.webix_point_left,
.webix_point_right {
  width: 7px;
  height: 13px;
}
.webix_point_top,
.webix_point_bottom,
.webix_point_right,
.webix_point_left {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA4AAAArCAIAAADHSy4DAAAABnRSTlMAAAAAAABupgeRAAAACXBIWXMAAABPAAAATwFjiv3XAAAAhElEQVR4nMXVQQoAIQhAUe9/FC/pLAYayUm/EeT6YWGmoqpWharKG7n+XK5nt9L/LurMeV27oZHrReN0M6Oupr5S1GU0vhN1J7L27hp1QYXX1WtE5UxnNXI0ep7+pEGRpr95ooWObbXUm1npXWkFaF3vTqj9c+h8pVOb7gK6Yeje4tvwARi4FgcAh2V/AAAAAElFTkSuQmCC);
}
.webix_point_top {
  background-position: 0 -36px;
}
.webix_point_bottom {
  background-position: 0 0;
}
.webix_point_right {
  background-position: 0 -22px;
}
.webix_point_left {
  background-position: 0 -9px;
}
/*basis*/
.webix_tree .webix_scroll_cont > .webix_tree_leaves {
  padding: 9px 10px 9px 9px;
}
.webix_tree_item {
  clear: both;
  height: 24px;
  line-height: 24px;
  white-space: nowrap;
}
.webix_tree_item.webix_selected {
  background: transparent;
}
.webix_tree_item.webix_selected span {
  padding: 4px 10px 4px 4px;
  margin-left: -4px;
  color: #ffffff;
  background: #fea223;
}
.webix_tree_checkbox {
  margin: 1px 0 0;
  padding: 0px;
  float: left;
  vertical-align: middle;
  height: 100%;
  width: 13px;
}
.webix_indeterminate {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAwAAAAMCAYAAABWdVznAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH3gcCCSwfRyGesAAAAAxpVFh0Q29tbWVudAAAAAAAvK6ymQAAAExJREFUKM9jLCgo+M9AAmBhYGBgaGtrY+Tk5MSrsLCwkIGBgeE/EwOJgGQNLMgcJSUlBgYGBnQ/Md67d498G+jsB6hbGQfWSYykJg0AUMsPVoNrFX0AAAAASUVORK5CYII=);
  background-repeat: no-repeat;
  background-position: left center;
  height: 100%;
  width: 13px;
  margin-top: 0 !important;
}
.webix_measure_size div {
  display: inline-block !important;
  margin-left: -5px;
  float: none;
}
.webix_tree_close,
.webix_tree_open,
.webix_tree_none,
.webix_tree_folder,
.webix_tree_file,
.webix_tree_folder_open {
  float: left;
  width: 20px;
  height: 100%;
  cursor: pointer;
  margin: 0px 0px 0px 0px;
  background-repeat: no-repeat;
  vertical-align: absmiddle;
}
.webix_tree_close,
.webix_tree_open,
.webix_tree_none {
  background-position: center center;
}
.webix_cell .webix_tree_close,
.webix_cell .webix_tree_open,
.webix_cell .webix_tree_none {
  background-color: transparent;
}
.webix_tree_folder,
.webix_tree_file,
.webix_tree_folder_open {
  background-position: 0 center ;
}
.webix_tree_file,
.webix_tree_folder,
.webix_tree_folder_open {
  margin: 0px 2px;
}
.webix_tree_leaves .webix_tree_leaves {
  margin-left: 18px;
}
.webixLineTree .webix_tree_leaves {
  margin-left: 0px;
}
.webix_tree_close {
  background-image: url(data:image/gif;base64,R0lGODlhEgASALMJAMrKyt3d3ejp6d7f3+/v75aWlvf39////wAAAP///wAAAAAAAAAAAAAAAAAAAAAAACH/C1hNUCBEYXRhWE1QPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4gPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iQWRvYmUgWE1QIENvcmUgNS4wLWMwNjAgNjEuMTM0Nzc3LCAyMDEwLzAyLzEyLTE3OjMyOjAwICAgICAgICAiPiA8cmRmOlJERiB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiPiA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIiB4bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC8iIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIiB4bWxuczpzdFJlZj0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL3NUeXBlL1Jlc291cmNlUmVmIyIgeG1wOkNyZWF0b3JUb29sPSJBZG9iZSBQaG90b3Nob3AgQ1M1IFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6M0I5RTczQjVDMDdBMTFFMTgxRjc4Mzk4M0Q3MjVFQzAiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6M0I5RTczQjZDMDdBMTFFMTgxRjc4Mzk4M0Q3MjVFQzAiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDozQjlFNzNCM0MwN0ExMUUxODFGNzgzOTgzRDcyNUVDMCIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDozQjlFNzNCNEMwN0ExMUUxODFGNzgzOTgzRDcyNUVDMCIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/PgH//v38+/r5+Pf29fTz8vHw7+7t7Ovq6ejn5uXk4+Lh4N/e3dzb2tnY19bV1NPS0dDPzs3My8rJyMfGxcTDwsHAv769vLu6ubi3trW0s7KxsK+urayrqqmop6alpKOioaCfnp2cm5qZmJeWlZSTkpGQj46NjIuKiYiHhoWEg4KBgH9+fXx7enl4d3Z1dHNycXBvbm1sa2ppaGdmZWRjYmFgX15dXFtaWVhXVlVUU1JRUE9OTUxLSklIR0ZFRENCQUA/Pj08Ozo5ODc2NTQzMjEwLy4tLCsqKSgnJiUkIyIhIB8eHRwbGhkYFxYVFBMSERAPDg0MCwoJCAcGBQQDAgEAACH5BAEAAAkALAAAAAASABIAAARJMMlJq704661B+SAIXAVhnKhBFKSZnmuLImhslXPN3ibi+6pdBXc4IIpB2YkGE1IKAoL0ICUInJNCYMDtDgJYiScUGnHO6LQkAgA7);
}
.webix_tree_open {
  background-image: url(data:image/gif;base64,R0lGODlhEgASALMJAMrKyt3d3ejp6d7f3+/v75aWlvf39wAAAP///////wAAAAAAAAAAAAAAAAAAAAAAACH/C1hNUCBEYXRhWE1QPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4gPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iQWRvYmUgWE1QIENvcmUgNS4wLWMwNjAgNjEuMTM0Nzc3LCAyMDEwLzAyLzEyLTE3OjMyOjAwICAgICAgICAiPiA8cmRmOlJERiB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiPiA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIiB4bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC8iIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIiB4bWxuczpzdFJlZj0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL3NUeXBlL1Jlc291cmNlUmVmIyIgeG1wOkNyZWF0b3JUb29sPSJBZG9iZSBQaG90b3Nob3AgQ1M1IFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6MzY0QzNGM0VDMDdBMTFFMUE3MDlCNUM2QjU1NDA5RjgiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6MzY0QzNGM0ZDMDdBMTFFMUE3MDlCNUM2QjU1NDA5RjgiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDozNjRDM0YzQ0MwN0ExMUUxQTcwOUI1QzZCNTU0MDlGOCIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDozNjRDM0YzREMwN0ExMUUxQTcwOUI1QzZCNTU0MDlGOCIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/PgH//v38+/r5+Pf29fTz8vHw7+7t7Ovq6ejn5uXk4+Lh4N/e3dzb2tnY19bV1NPS0dDPzs3My8rJyMfGxcTDwsHAv769vLu6ubi3trW0s7KxsK+urayrqqmop6alpKOioaCfnp2cm5qZmJeWlZSTkpGQj46NjIuKiYiHhoWEg4KBgH9+fXx7enl4d3Z1dHNycXBvbm1sa2ppaGdmZWRjYmFgX15dXFtaWVhXVlVUU1JRUE9OTUxLSklIR0ZFRENCQUA/Pj08Ozo5ODc2NTQzMjEwLy4tLCsqKSgnJiUkIyIhIB8eHRwbGhkYFxYVFBMSERAPDg0MCwoJCAcGBQQDAgEAACH5BAEAAAkALAAAAAASABIAAARDMMlJq704661B+SAIXAVhnKhBFKSZnmv7wqxVzmpd3Uff5zKEUAi0uV4xm4DAbBIEOkohMKhaB4HoxBMKjTjgsFgSAQA7);
}
.webix_tree_file {
  background-image: url(data:image/gif;base64,R0lGODlhEgASAIABAI6Pj////yH5BAEKAAEALAAAAAASABIAAAInjI+JwM26XAtPyTnTfU5veGyXJ2ZhaRpoSq0AicKlLNJftNojyCMFADs=);
}
.webix_tree_folder {
  background-image: url(data:image/gif;base64,R0lGODlhEgASAIABAI6Pj////yH5BAEKAAEALAAAAAASABIAAAIhjI+py90AI3Syvoqj27mfnn2gZYxkYEpiCqypa27yTC8FADs=);
}
.webix_tree_folder_open {
  background-image: url(data:image/gif;base64,R0lGODlhEgASAIABAI6Pj////yH5BAEKAAEALAAAAAASABIAAAIjjI+py90AI3SyvorjkQ7pDAJBSJaTaGpjKq7pxsJmR9c2UwAAOw==);
}
.webix_tree_img {
  background: transparent;
  float: left;
  width: 18px;
  height: 24px;
  background-position: 0 0;
}
.webix_tree_plus2 {
  background-image: url(data:image/gif;base64,R0lGODlhEgAYAMIDAFVVVYiIiMHBwf///////////////////yH5BAEKAAQALAAAAAASABgAAAM8SLoq/LDFKWl0FuLMNq8faAVkWVLBoK5DgK7A6k6pGqtzlAI83wpAIKM2uLVeNhmSdaSZTKGodEqtWjkJADs=);
  background-repeat: no-repeat;
}
.webix_tree_plus3 {
  background-image: url(data:image/gif;base64,R0lGODlhEgAYAMIDAFVVVYiIiMHBwf///////////////////yH5BAEKAAQALAAAAAASABgAAANCSLoq/LDFKWl0FuLMNq8faAVkWVLBoK5DgK7A6k6pGqtzlAI83wpAIKM2uLVeNhmSdaSZTB9PNLSQcqwZrEVL4SYAADs=);
}
.webix_tree_plus4 {
  background-image: url(data:image/gif;base64,R0lGODlhEgAYAMIDAFVVVYiIiMHBwf///////////////////yH5BAEKAAQALAAAAAASABgAAAM5SLrc/jDKSau9mIbNeQxDKA7BJwJiCYEhGqoPCMwzKdw3ww4uabap38i36nQqgkwSs7w0LU+kMpIAADs=);
}
.webix_tree_minus2 {
  background-image: url(data:image/gif;base64,R0lGODlhEgAYAMIDAFVVVYiIiMHBwf///////////////////yH5BAEKAAQALAAAAAASABgAAAM5SLoq/LDFKWl0FuLMNq8faAVkWVLBoK5DgLKrO6Vw+wI43go8z9AwWQTIEkKIMZTJFGo6n9ColJMAADs=);
  background-repeat: no-repeat;
}
.webix_tree_minus3 {
  background-image: url(data:image/gif;base64,R0lGODlhEgAYAMIDAFVVVYiIiMHBwf///////////////////yH5BAEKAAQALAAAAAASABgAAAM+SLoq/LDFKWl0FuLMNq8faAVkWVLBoK5DgLKrO6Vw+wI43go8z9AwWQTIEkKIMZTJ9PE0QwsnR5qhWqwUbAIAOw==);
}
.webix_tree_minus4 {
  background-image: url(data:image/gif;base64,R0lGODlhEgAYAMIDAFVVVYiIiMHBwf///////////////////yH5BAEKAAQALAAAAAASABgAAAM1SLrc/jDKSau9mIbNeQxDKA7BN4olBJ6kCbwvKcwzs57pc4+5s6OfTqciyBQxx0vSsiQaIwkAOw==);
}
.webix_tree_line1 {
  background-image: url(data:image/gif;base64,R0lGODlhEgASAMQBAMHBwQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAAEALAAAAAASABIAAAUmYCCOIkCeaJmuKpuaLgrH5Ey3N57bN0/7MaBLyCKujK/cCCljhQAAOw==);
}
.webix_tree_line2 {
  background-image: url(data:image/gif;base64,R0lGODlhEgASAMQBAMHBwQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAAEALAAAAAASABIAAAUiYCCOIkCeaJmuKpuaLgrH5Ey3N57bN+D/wJxwSCwaj0hSCAA7);
  background-repeat: no-repeat;
}
.webix_tree_line3 {
  background-image: url(data:image/gif;base64,R0lGODlhEgASAMQBAMHBwQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAAEALAAAAAASABIAAAUoYCCOIkCeaJmuKpuaLgrH5Ey3N57bN+D/wBWPNowVXUdWUpgbLV+sEAA7);
}
.webix_tree_line4 {
  background-image: url(data:image/gif;base64,R0lGODlhEgASAMQBAMHBwQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAAEALAAAAAASABIAAAUcYCCOZGmeaKqubOu+MAzMdI0CMS7n/O6/OmAqBAA7);
}
.webix_tree_blank {
  background-image: url(data:image/gif;base64,R0lGODlhAQABAPABAP///wAAACH5BAEKAAAALAAAAAABAAEAAAICRAEAOw==);
}
.webix_tree_img {
  background-color: #ffffff;
}
.webix_cal_month {
  height: 22px;
  line-height: 20px;
  text-align: center;
  position: relative;
  font-size: 14px;
  font-weight: bold;
  padding-top: 17px;
  padding-bottom: 5px;
  box-sizing: content-box;
}
.webix_cal_prev_button,
.webix_cal_next_button {
  cursor: pointer;
  position: absolute;
  top: 17px;
  width: 30px;
  height: 42px;
  background-repeat: no-repeat;
  background-position: 11.5px 4px;
}
.webix_cal_prev_button {
  left: 17px;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAcAAAALCAYAAACzkJeoAAAASUlEQVR42p2QMQoAQQgD79EZ0Mqn5xCu2cPdYgUbJ0rMMxXgLeiuKq8gsJAz8weQ0QiwJEfECnr4wdlEnwJ68+yyhReC+c85oRecj0Um+pmo9wAAAABJRU5ErkJggg==);
  background-repeat: no-repeat;
}
.webix_cal_next_button {
  right: 17px;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAcAAAALCAYAAACzkJeoAAAARElEQVR42qXPsQoAIAhF0T76PdDJT7cUmtQhcmk4N8QVQ9JXN2bmgWOgqp+BiCRG2AYAMoi3/LxYdyagAnhA6G93TrABZaJFJjrFY8IAAAAASUVORK5CYII=);
  background-repeat: no-repeat;
}
.webix_view > .webix_cal_header {
  margin: 0px 17px 10px 17px;
  height: auto;
}
.webix_view > .webix_cal_header div {
  float: left;
  text-align: center;
  height: 19px;
  font-size: 11px;
  color: #555555;
  border-bottom: #cecece 1px solid ;
  margin-bottom: 7px;
}
.webix_cal_body {
  margin: 0px 17px 0px 17px;
}
.webix_cal_body .webix_cal_row {
  clear: both;
}
.webix_cal_body .webix_cal_row > div {
  float: left;
  text-align: center;
  height: 100%;
}
.webix_cal_body .webix_selected,
.webix_cal_body .webix_cal_select,
.webix_cal_body .webix_cal_select.webix_cal_today {
  color: #ffffff;
  background: #fea223;
}
.webix_cal_day,
.webix_cal_week_num {
  /*line-height: 29px;*/
  cursor: pointer;
  font-size: 12px;
  color: #555555;
}
.webix_cal_week_num {
  color: #aeaeae;
  cursor: default;
  margin-right: 0px;
  border-right: 1px solid #cecece;
}
.webix_cal_event {
  font-weight: bold;
  color: #C66200;
}
.webix_cal_outside {
  color: #bbbbbb;
}
.webix_cal_inactive {
  background: #888;
}
.webix_cal_inactive {
  background: #888;
}
.webix_cal_day_disabled {
  color: #bbbbbb;
  background: #f4f4f4 !important;
}
.webix_cal_month_name {
  cursor: pointer;
}
.webix_cal_block {
  float: left;
  text-align: center;
  cursor: pointer;
}
.webix_selected {
  background: #fea223;
  color: #ffffff;
}
.webix_cal_footer {
  text-align: center;
  font-size: 12px;
  color: #444;
  margin: 4px 17px;
  padding-top: 2px;
  cursor: pointer;
}
.webix_cal_icons {
  float: right;
  padding: 4px 4px;
}
.webix_cal_time {
  padding: 2px 4px;
}
.webix_cal_time_icons {
  float: left;
}
.webix_cal_icons .webix_cal_icon {
  text-align: center;
  padding: 2px 4px;
}
.webix_cal_icon:hover,
.webix_cal_time:hover,
.webix_cal_month_name:hover {
  text-decoration: underline;
  color: #3389ff;
}
.webix_cal_month_name.webix_readonly:hover {
  text-decoration: none;
  color: #555555;
  cursor: default;
}
.webix_time_header {
  padding: 17px 17px 1px 17px;
}
.webix_time_header .webix_cal_hours,
.webix_time_header .webix_cal_minutes {
  display: inline-block;
  font-size: 14px;
  text-align: center;
  height: 26px;
  line-height: 22px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  box-shadow: 0 1px 1px #FFFFFF inset;
  border-bottom: 1px solid #c8c8c8;
}
.webix_time_header .webix_cal_minutes {
  padding-left: 1px;
  border-left: none;
}
.webix_time_header .webix_cal_hours {
  border-right: none !important;
}
.webix_cal_body .webix_hours {
  float: left;
  border-right: 1px solid #cecece;
  padding-right: 1px;
}
.webix_cal_body .webix_minutes {
  float: left;
  padding-left: 1px;
}
.webix_cal_block_empty {
  float: left;
  text-align: center;
}
.webix_time_footer {
  text-align: center;
  font-size: 12px;
  padding: 7px 17px 0 17px;
  cursor: pointer;
}
.webix_cal_done {
  margin-top: 3px;
  padding: 2px 7px;
  font-size: 12px;
  border-radius: 0px;
  border: 1px solid #c8c8c8;
  background: #006bff;
  text-shadow: none !important;
  color: #ffffff !important;
  border: 1px solid #006bff;
  font-size: 15px !important;
  float: right;
}
.webix_cal_blurred_hours {
  background-color: #f7f7f7;
}
.webix_property_line {
  clear: both;
  width: 100%;
  min-height: 24px;
  height: auto;
}
.webix_property_line:nth-child(odd) {
  background-color: #ebebeb;
}
.webix_property_label,
.webix_property_value {
  height: 24px;
  line-height: 24px;
  padding-left: 10px;
  float: left;
  border-bottom: 1px solid #c8c8c8;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  overflow: hidden;
}
.webix_property_label {
  border-right: 1px solid #c8c8c8;
}
.webix_property_label_line {
  padding-left: 10px;
  font-size: 13px;
  background: #ffffff;
  line-height: 34px;
  line-height: 23px;
  border-bottom: 1px solid transparent;
}
.webix_property_label_line .webix_el_label,
.webix_property_label_line .webix_inp_label {
  font-size: 13px;
}
.webix_property_label_line .webix_el_button {
  color: #555555 !important;
}
.webix_property_label_line .webix_el_button input,
.webix_property_label_line .webix_el_toggle input {
  border: none;
}
.webix_property_col_val {
  width: 100%;
  height: 100%;
  -moz-user-select: text;
  -webkit-user-select: text;
  user-select: text;
}
.webix_property_col_ind {
  float: right;
  border: 1px solid #c8c8c8;
  border-radius: 2px;
  width: 30px;
  cursor: pointer;
  height: 13px;
  margin: 3px 10px 3px 0;
}
.webix_property_value {
  text-overflow: ellipsis;
  white-space: nowrap;
}
.webix_property_check {
  margin-top: 5px;
}
/*style used by tooltip's container*/
.webix_tooltip {
  display: none;
  position: absolute;
  z-index: 10000;
  background-color: white;
  padding: 5px 10px;
  border: 1px solid #c8c8c8;
  font-family: Arial;
  font-size: 13px;
  color: #555555;
  border-radius: 3px;
  box-shadow: 1px 1px 0px 0px #CCC;
}
.webix_color_row {
  clear: both;
  white-space: nowrap;
}
.webix_color_palette {
  text-align: left;
}
.webix_color_row,
.webix_color_row div,
.webix_color_selector {
  line-height: 0;
  font-size: 0;
}
.webix_color_row div {
  display: inline-block;
  width: 15px;
  height: 15px;
  cursor: default;
}
.webix_color_selector {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  position: relative;
  border: 2px solid #f3f3f3;
}
.webix_view.webix_toolbar .webix_el_button {
  background: transparent;
}
.webix_el_button input,
.webix_el_toggle input,
.webix_el_button button,
.webix_el_toggle button,
.webixbutton {
  border-radius: 0px;
  border: 1px solid #c8c8c8;
  height: 100%;
  width: 100%;
  cursor: pointer;
  font-size: 13px;
  font-family: Arial;
  color: #ffffff;
  font-size: 15px;
  border: 1px solid #3389ff !important;
  -webkit-appearance: none;
}
.webix_el_button .webix_img_btn,
.webix_el_toggle .webix_img_btn,
.webix_el_button .webix_img_btn_top,
.webix_el_toggle .webix_img_btn_top {
  color: #555555;
}
.webix_el_button .webix_img_btn .webix_img_btn_text,
.webix_el_toggle .webix_img_btn .webix_img_btn_text,
.webix_el_button .webix_img_btn_top .webix_img_btn_text,
.webix_el_toggle .webix_img_btn_top .webix_img_btn_text {
  color: #555555;
}
.webix_el_button .webix_img_btn,
.webix_el_toggle .webix_img_btn,
.webix_el_button .webix_img_btn_top,
.webix_el_toggle .webix_img_btn_top {
  border: 0;
}
.webixtype_base,
.webixtype_prev,
.webixtype_next,
.webixbutton {
  background: #3389ff;
  font-size: 15px !important;
  color: #ffffff;
  font-size: 15px;
  border: 1px solid #3389ff !important;
  padding: 0px;
  border: 0px;
}
.webixtype_form {
  background: #006bff;
  text-shadow: none !important;
  color: #ffffff !important;
  border: 1px solid #006bff;
  font-size: 15px !important;
}
.webix_el_button .webixtype_danger {
  background: #ce5545;
  border: 1px solid #ce5545 !important;
  color: #fff !important;
  font-size: 15px !important;
}
.webix_el_button .webix_el_box,
.webix_el_toggle .webix_el_box {
  position: relative;
}
.webix_el_button .webix_el_arrow,
.webix_el_toggle .webix_el_arrow {
  position: absolute;
  z-index: 1;
}
.webixtype_prev,
.webixtype_next {
  position: absolute;
  z-index: 2;
  top: 0px;
}
input.webixtype_prev {
  border-left-width: 0;
  border-radius: 0px;
  -webkit-border-top-left-radius: 0;
  -webkit-border-bottom-left-radius: 0;
  -webkit-border-top-right-radius: 0px;
  -webkit-border-bottom-right-radius: 0px;
  -moz-border-radius-topleft: 0;
  -moz-border-radius-bottomleft: 0;
  -moz-border-radius-topright: 0px;
  -moz-border-radius-bottomright: 0px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-top-right-radius: 0px;
  border-bottom-right-radius: 0px;
}
input.webixtype_next {
  border-right-width: 0;
  border-radius: 0pxt;
  -webkit-border-top-left-radius: 0px;
  -webkit-border-bottom-left-radius: 0px;
  -webkit-border-top-right-radius: 0;
  -webkit-border-bottom-right-radius: 0;
  -moz-border-radius-topleft: 0px;
  -moz-border-radius-bottomleft: 0px;
  -moz-border-radius-topright: 0;
  -moz-border-radius-bottomright: 0;
  border-top-left-radius: 0px;
  border-bottom-left-radius: 0px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.webix_el_arrow {
  width: 18px;
  height: 18px;
  background: #3389ff;
  color: #ffffff;
  font-size: 15px !important;
  border: 1px solid #3389ff !important;
  border: 1px solid #c8c8c8;
}
.webixtype_prev_arrow {
  -webkit-transform: rotate(-45deg);
  -moz-transform: rotate(-45deg);
  -ms-transform: rotate(-45deg);
  -o-transform: rotate(-45deg);
}
.webixtype_next_arrow {
  -webkit-transform: rotate(45deg);
  -moz-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -o-transform: rotate(45deg);
}
.webix_img_btn_abs_top .webix_icon,
.webix_img_btn_top .webix_icon {
  font-size: 22px;
  position: absolute;
  top: 8px;
  left: 50%;
}
.webix_img_btn_abs .webix_icon {
  margin-left: 4px;
}
.webix_img_btn_abs.webix_img_btn_abs_top .webix_icon,
.webix_img_btn_top .webix_icon {
  margin-left: -10px;
}
.webix_img_btn,
.webix_img_btn_top {
  vertical-align: top;
  background-color: transparent;
  border: none;
  width: 100%;
  padding: 0;
}
.webix_img_btn,
.webix_img_btn_top,
.webix_img_btn_abs {
  cursor: pointer;
  text-align: left;
  background-repeat: no-repeat;
  background-position: 2px center;
  height: 100%;
  font-size: 13px;
}
.webix_img_btn .webix_icon,
.webix_img_btn_top .webix_icon,
.webix_img_btn_abs .webix_icon {
  color: #ffffff;
}
.webix_img_btn_abs,
.webix_img_btn {
  padding: 0;
}
.webix_img_btn_abs .webix_image,
.webix_img_btn .webix_image {
  background-repeat: no-repeat;
  background-position: center center;
  float: left;
  vertical-align: top;
}
.webix_img_btn_abs.webix_img_btn_abs_top .webix_image {
  background-position: center 5px;
}
/*.webix_img_btn:hover, .webix_img_btn_top:hover{
	background-color: #ddd;
	background-color: rgba(250,250,250,0.5);
};*/
/*.webix_img_btn:active, .webix_img_btn_top:active{
	background-color: #ddd;
	background-color: rgba(100,100,100,0.1);
};*/
.webix_img_btn_top {
  text-align: center;
  background-position: center 5px;
}
.webix_img_btn_text {
  position: absolute;
  left: 0;
  bottom: 3px;
  width: 100%;
  text-align: center;
  cursor: pointer;
  color: #ffffff;
}
.webix_img_btn_abs {
  /*position:absolute;
	top:0px; left:0px;
	width:100%;*/
  background-position: center center;
}
.webix_img_btn_top {
  background-position: center top;
  vertical-align: top;
}
.webix_img_btn_abs .webix_img_btn_text {
  bottom: 8px;
}
.webix_pressed .webix_img_btn,
.webix_pressed .webix_img_btn_top {
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  background-color: rgba(0, 0, 0, 0.05);
}
.webix_pressed .webix_img_btn_abs + input,
.webix_pressed .webixtype_base {
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.webix_disabled_box .webixtype_base,
.webix_disabled_box .webixtype_prev,
.webix_disabled_box .webixtype_next,
.webix_disabled_box .webixtype_danger,
.webix_disabled_box .webixtype_form,
.webix_disabled_box .webix_el_arrow {
  color: #aaaaaa !important;
  background: #e9e9e9 !important;
  border: 1px solid #e6e6e6 !important;
  text-shadow: none !important;
}
.webixbutton {
  width: auto;
  height: auto;
  padding: 8px 15px;
}
.webix_control {
  background: transparent;
}
.webix_control input,
.webix_control button,
.webix_control textarea,
.webix_el_label,
.webix_inp_label,
.webix_inp_top_label,
.webix_inp_bottom_label {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  font-family: Arial;
}
.webix_el_box {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  padding: 2px 2px;
  height: 100%;
  width: 100%;
  font-size: 13px;
}
.webix_el_text input,
.webix_el_search input,
.webix_el_combo input,
.webix_el_datepicker input {
  height: 100%;
  padding: 0px 10px;
  border: 1px solid #c8c8c8;
  font-family: Arial;
  font-size: 13px;
  color: #555555;
  background-color: #ebebeb;
  border-color: #ebebeb !important;
  -webkit-appearance: none;
  border-radius: 0;
  padding-top: 4px\0;
}
.webix_inp_label,
.webix_inp_top_label,
.webix_label_right {
  color: #555555;
  text-transform: none;
  font-size: 13px;
}
/*.webix_toolbar .webix_inp_label{
	padding-top:(@inputHeight - 11 )/2;
}*/
.webix_inp_label {
  float: left;
  padding-top: 2px;
  padding-left: 2px;
  padding-right: 7.5px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
}
.webix_inp_top_label {
  float: none;
  padding: 2px 2px;
  padding-bottom: 0px;
}
.webix_inp_bottom_label {
  font-size: 11px;
  color: #626262;
}
.webix_label_right {
  padding-left: 7.5px;
}
.webix_el_checkbox .webix_label_right {
  display: inline-block;
  padding-top: 2px;
}
.webix_el_label {
  color: #555555;
  line-height: 26px;
  padding: 2px 2px;
}
.webix_toolbar .webix_el_label {
  padding-left: 10px;
  text-transform: none;
}
.webix_el_select select {
  height: 100%;
  font-size: 13px;
  font-family: Arial;
  border: 1px solid #c8c8c8;
}
body:not(:-moz-handler-blocked) .webix_el_select select {
  padding: .2em;
}
.webix_el_group,
.webix_all_segments {
  height: 100%;
  white-space: nowrap;
}
.webix_inp_counter_next,
.webix_inp_counter_prev,
.webix_inp_counter_value {
  border: 1px solid #c8c8c8;
  cursor: pointer;
  -webkit-appearance: none;
  width: 20px;
  height: 100%;
  vertical-align: top;
}
.webix_inp_counter_value {
  font-size: 13px;
  width: 50px;
  color: #555555;
  text-align: center;
  border-left-width: 0px;
  border-right-width: 0px;
  padding-top: 4px\0;
  -webkit-appearance: none;
  border-radius: 0;
}
/*body:not(:-moz-handler-blocked) .webix_inp_counter_value{
	 position:relative; top:-1px;
}*/
.webix_inp_counter_prev {
  padding-left: 6px;
  background: #3389ff;
  color: #ffffff;
  font-size: 15px !important;
  border: 1px solid #3389ff !important;
  -webkit-border-top-left-radius: 0px;
  -webkit-border-bottom-left-radius: 0px;
  -webkit-border-top-right-radius: 0;
  -webkit-border-bottom-right-radius: 0;
  -moz-border-radius-topleft: 0px;
  -moz-border-radius-bottomleft: 0px;
  -moz-border-radius-topright: 0;
  -moz-border-radius-bottomright: 0;
  border-top-left-radius: 0px;
  border-bottom-left-radius: 0px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.webix_inp_counter_next {
  padding-left: 6px;
  background: #3389ff;
  color: #ffffff;
  font-size: 15px !important;
  border: 1px solid #3389ff !important;
  -webkit-border-top-left-radius: 0;
  -webkit-border-bottom-left-radius: 0;
  -webkit-border-top-right-radius: 0px;
  -webkit-border-bottom-right-radius: 0px;
  -moz-border-radius-topleft: 0;
  -moz-border-radius-bottomleft: 0;
  -moz-border-radius-topright: 0px;
  -moz-border-radius-bottomright: 0px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-top-right-radius: 0px;
  border-bottom-right-radius: 0px;
}
.webix_el_textarea textarea {
  border: 1px solid #c8c8c8;
  height: 100%;
  margin: 0;
  padding: 5px;
  color: #555555;
  resize: none;
  font-size: 13px;
  font-family: Arial;
  padding-left: 10px;
  padding-right: 10px;
}
.webix_el_textarea .webix_inp_label {
  padding-top: 6.5px;
}
.webix_segment_0,
.webix_segment_1 {
  border: 1px solid #c8c8c8;
  border-right-width: 0px;
  height: 100%;
}
.webix_segment_0 {
  -webkit-border-top-left-radius: 0px;
  -webkit-border-bottom-left-radius: 0px;
  -webkit-border-top-right-radius: 0;
  -webkit-border-bottom-right-radius: 0;
  -moz-border-radius-topleft: 0px;
  -moz-border-radius-bottomleft: 0px;
  -moz-border-radius-topright: 0;
  -moz-border-radius-bottomright: 0;
  border-top-left-radius: 0px;
  border-bottom-left-radius: 0px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.webix_segment_N {
  border: 1px solid #c8c8c8;
  height: 100%;
  -webkit-border-top-left-radius: 0;
  -webkit-border-bottom-left-radius: 0;
  -webkit-border-top-right-radius: 0px;
  -webkit-border-bottom-right-radius: 0px;
  -moz-border-radius-topleft: 0;
  -moz-border-radius-bottomleft: 0;
  -moz-border-radius-topright: 0px;
  -moz-border-radius-bottomright: 0px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-top-right-radius: 0px;
  border-bottom-right-radius: 0px;
}
.webix_segment_0,
.webix_segment_1,
.webix_segment_N {
  -webkit-appearance: none;
  background: #3389ff;
  font-size: 15px !important;
  color: #ffffff;
  font-size: 15px;
  border: 1px solid #3389ff !important;
  cursor: pointer;
  padding: 0;
}
.webix_segment_0.webix_selected,
.webix_segment_1.webix_selected,
.webix_segment_N.webix_selected {
  color: #ffffff;
  background: #fea223;
  /*background: @buttonColor;
	border: 1px solid @buttonColor;
	text-shadow: none !important;
	color: @buttonFontColor !important;*/
  border: 1px solid #fea223 !important;
}
.webix_inp_static {
  border: 1px solid #c8c8c8;
  background: white;
  overflow: hidden;
  padding: 0px 10px;
  height: 100%;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  float: left;
}
.webix_inp_static .webix_placeholder {
  color: #a2a2a2;
}
.webix_el_combo,
.webix_el_richselect,
.webix_el_datepicker,
.webix_el_colorpicker,
.webix_el_search {
  font-size: 13px;
}
.webix_el_combo .webix_el_box,
.webix_el_richselect .webix_el_box,
.webix_el_datepicker .webix_el_box,
.webix_el_colorpicker .webix_el_box,
.webix_el_search .webix_el_box {
  color: #555555;
  position: relative;
}
.webix_el_combo input,
.webix_el_richselect input,
.webix_el_datepicker input,
.webix_el_colorpicker input,
.webix_el_search input,
.webix_el_combo .webix_inp_static,
.webix_el_richselect .webix_inp_static,
.webix_el_datepicker .webix_inp_static,
.webix_el_colorpicker .webix_inp_static,
.webix_el_search .webix_inp_static {
  padding-right: 24px;
  font-family: Arial;
  font-size: 13px;
  color: #555555;
  background-color: #ebebeb;
  border-color: #ebebeb !important;
  -webkit-appearance: none;
}
.webix_el_combo .webix_input_icon,
.webix_el_richselect .webix_input_icon,
.webix_el_datepicker .webix_input_icon,
.webix_el_colorpicker .webix_input_icon,
.webix_el_search .webix_input_icon {
  right: 2px;
  background: transparent;
  z-index: 1;
  position: absolute;
}
.webix_el_combo .webix_input_icon,
.webix_el_richselect .webix_input_icon {
  padding-left: 7px;
  width: 19px;
}
.webix_el_datepicker .webix_input_icon,
.webix_el_colorpicker .webix_input_icon,
.webix_el_search .webix_input_icon {
  padding-left: 5px;
  width: 21px;
}
.webix_el_radio .webix_inp_label {
  line-height: normal !important;
  padding-top: 6.5px;
}
.webix_inp_radio_border input,
.webix_el_checkbox input {
  margin: 0px;
  padding: 0px;
  float: left;
}
.webix_line_break {
  clear: both;
}
.webix_line_break {
  height: 4.5px;
}
.webix_radio_option {
  display: table;
  float: left;
  margin-top: 4.5px;
  margin-right: 20px;
}
.webix_inp_radio_border,
.webix_el_radio .webix_label_right {
  display: table-cell;
  vertical-align: middle;
}
.webix_invalid .webix_el_box input,
.webix_invalid .webix_custom_radio,
.webix_invalid .webix_el_box .webix_inp_static,
.webix_invalid .webix_el_box select,
.webix_invalid .webix_el_box textarea,
input.webix_invalid,
select.webix_invalid,
textarea.webix_invalid {
  background-color: #fff6f6;
  border-color: #fea5a8;
}
.webix_invalid .webix_inp_bottom_label {
  font-size: 11px;
  color: #fd595f;
}
.webix_el_colorpicker .webix_inp_static div {
  float: right;
  width: 18px;
  height: 18px;
  margin: 2px -16px 0px -5px;
  border-radius: 0px;
}
.webix_el_search .webix_el_box {
  position: relative;
}
.webix_el_search input {
  padding-right: 30px;
}
.webix_el_search span {
  position: absolute;
  right: 15px;
  cursor: pointer;
  padding-left: 7px;
}
.webix_view.webix_control > .webix_disabled {
  filter: progid:DXImageTransform.Microsoft.Alpha(opacity=0);
  opacity: 0;
}
.webix_view.webix_control .webix_disabled_box label,
.webix_view.webix_control .webix_disabled_box .webix_input_icon,
.webix_view.webix_control .webix_disabled_box button {
  color: #aaaaaa;
}
.webix_view.webix_control .webix_disabled_box input,
.webix_view.webix_control .webix_disabled_box select,
.webix_view.webix_control .webix_disabled_box textarea,
.webix_view.webix_control .webix_disabled_box .webix_inp_static {
  color: #aaaaaa;
  background: #eeeeee;
}
.webix_view.webix_control .webix_disabled_box .webix_inp_counter_prev,
.webix_view.webix_control .webix_disabled_box .webix_inp_counter_next,
.webix_view.webix_control .webix_disabled_box .webix_segment_0,
.webix_view.webix_control .webix_disabled_box .webix_segment_1,
.webix_view.webix_control .webix_disabled_box .webix_segment_N {
  color: #aaaaaa !important;
  background: #e9e9e9 !important;
  border: 1px solid #e6e6e6 !important;
  text-shadow: none !important;
}
.webix_disabled_top_label {
  color: #aaaaaa;
}
label.webix_required:after {
  padding-left: 4px;
  content: "*";
  color: red;
}
.webix_multicombo .webix_inp_static {
  padding: 0 3px;
}
.webix_el_text .webix_multicombo_input {
  background-color: transparent;
  border: 0;
  float: left;
  vertical-align: middle;
  padding: 0px;
  color: #555555;
  font-size: 13px;
  font-family: Arial;
  margin-left: 7px;
}
.webix_el_text .webix_multicombo_input:focus {
  border: 0;
  box-shadow: none;
}
.webix_multicombo_listbox {
  width: auto;
  line-height: 1;
  margin: 0;
  padding: 0;
  list-style: none;
}
.webix_multicombo_value {
  padding: 0 5px 0 7px;
  background-color: #f2f2f2;
  display: inline-block;
  margin: 3px;
  float: left;
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
  border-radius: 0px;
}
.webix_multicombo_delete {
  margin-left: 10px;
  padding: 0 5px ;
  color: #2f2f2f;
  cursor: pointer;
}
.webix_multilist .webix_selected {
  background: #f2f2f2;
  color: #555555;
}
.webix_el_tabbar {
  background: transparent;
}
.webix_all_tabs {
  height: 100%;
  display: table;
}
.webix_tab_filler {
  display: table-cell;
  background: transparent;
  font-size: 1px;
  border-bottom: 1px solid #c8c8c8;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_tab_filler:first-child {
  border-right: 1px solid #c8c8c8;
}
.webix_item_tab:first-child {
  border-left: 1px solid #c8c8c8;
}
.webix_item_tab {
  display: table-cell;
  text-align: center;
  vertical-align: middle;
  overflow: hidden;
  cursor: pointer;
  border: 1px solid #c8c8c8;
  border-left-width: 0px;
  background-color: #ebebeb;
  -webkit-border-top-left-radius: 0;
  -webkit-border-bottom-left-radius: 0px;
  -webkit-border-top-right-radius: 0;
  -webkit-border-bottom-right-radius: 0px;
  -moz-border-radius-topleft: 0;
  -moz-border-radius-bottomleft: 0px;
  -moz-border-radius-topright: 0;
  -moz-border-radius-bottomright: 0px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webixtype_bottom .webix_item_tab {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.webix_item_tab.webix_selected {
  border-bottom-width: 0px;
  color: #555555;
  border: 1px solid #c8c8c8;
  border-bottom: 0 !important;
  background: #ffffff;
}
.webixtype_bottom .webix_item_tab.webix_selected {
  border-bottom-width: 1px ;
  color: #ffffff;
  background: #fea223;
}
.webix_before_all_tabs {
  width: 100%;
}
.webix_after_all_tabs {
  width: 100%;
  border-left: 1px solid #c8c8c8;
  border-right: 1px solid #c8c8c8;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_view.webix_control .webix_disabled_box .webix_item_tab {
  color: #aaaaaa !important;
  background: #e9e9e9 !important;
  border: 1px solid #e6e6e6 !important;
  text-shadow: none !important;
}
.webix_el_tabbar .webixtype_icon .webix_img_btn {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  margin: 0 auto;
  text-align: center;
}
.webix_el_tabbar .webixtype_icon .webix_img_btn .webix_icon_btn {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  margin: 0 3px;
}
.webix_el_tabbar .webixtype_icon .webix_item_tab,
.webix_el_tabbar .webixtype_iconTop .webix_item_tab,
.webix_el_tabbar .webixtype_image .webix_item_tab {
  padding: 2px 0;
  border-radius: 0;
}
.webix_el_tabbar .webixtype_icon .webix_img_btn_top,
.webix_el_tabbar .webixtype_iconTop .webix_img_btn_top,
.webix_el_tabbar .webixtype_image .webix_img_btn_top {
  background-position: center 0;
  position: relative;
  height: 100%;
}
.webix_tab_more_icon {
  cursor: pointer;
  display: table-cell;
  overflow: hidden;
  text-align: center;
  box-sizing: border-box;
  vertical-align: middle;
  padding: 0 3px;
}
.webix_tab_more_icon .webix_icon {
  width: 100%;
}
.webix_tab_list .webix_list_item:last-child {
  border-bottom: none;
}
.webix_icon.webix_tab_close {
  font-size: 12px;
  float: right;
  padding: 4px;
  margin-top: -4px;
}
.webix_menu,
.webix_menu-x {
  background: #ffffff;
}
.webix_menu .webix_list_item:hover,
.webix_menu-x .webix_list_item:hover,
.webix_menu .webix_list_item:active,
.webix_menu-x .webix_list_item:active {
  background: rgba(100, 100, 100, 0.1);
}
.webix_menu .webix_list_item,
.webix_menu-x .webix_list_item {
  border: none;
  text-decoration: none;
  background: #ffffff;
  height: 36px;
}
.webix_menu .webix_list_item .webix_submenu_icon,
.webix_menu-x .webix_list_item .webix_submenu_icon {
  float: right;
  text-align: right;
  position: relative;
  margin-left: 4px;
}
.webix_menu-x .webix_list_item:first-child {
  margin-left: 0;
}
.webix_menu-x .webix_submenu_icon {
  top: 14px;
}
.webix_menu-x {
  background-color: white;
  border: none;
  background: transparent;
}
.webix_menu-x .webix_list_item {
  display: inline-block;
  line-height: 32px;
}
.webix_menu-x .webix_list_item {
  border-right: 1px solid #ffffff;
  border-left: 0px;
  background: #3389ff;
  color: #ffffff;
  font-size: 15px;
}
.webix_menu-x .webix_list_item .webix_submenu_icon {
  border-color: #ffffff transparent transparent transparent;
}
.webix_menu-x .webix_list_item .webix_icon_btn {
  color: #ffffff;
}
.webix_menu-x .webix_list_item:hover,
.webix_menu-x .webix_list_item:active {
  background: #006bff;
  color: #ffffff;
}
.webix_menu-x .webix_list_item:hover .webix_icon_btn,
.webix_menu-x .webix_list_item:active .webix_icon_btn {
  color: #fff;
}
.webix_menu-x .webix_list_item:last-child {
  border-right: none;
}
/* Submenu */
.webix_menu {
  background: #ffffff;
  border: 1px solid #c8c8c8;
  border-radius: 0px;
}
.webix_menu .webix_list_item {
  display: block;
}
.webix_menu .webix_context_separator {
  height: 3px;
  padding: 1px 3px 0 3px;
}
.webix_menu .webix_context_separator .sep_line {
  height: 1px;
  border-top: 1px solid #c8c8c8;
}
.webix_menu .webix_submenu_icon {
  top: 12px;
}
.webix_menu .webix_context_spacer {
  height: 32px;
}
.webix_menu_link {
  color: inherit;
  text-decoration: none;
  display: block;
  height: 100%;
}
/* Toolbar */
.webix_layout_toolbar {
  background: #ffffff;
}
.webix_layout_toolbar .webix_el_label,
.webix_layout_toolbar .webix_inp_label {
  font-size: 13px;
}
.webix_layout_toolbar .webix_el_button {
  color: #555555 !important;
}
.webix_layout_toolbar .webix_el_button input,
.webix_layout_toolbar .webix_el_toggle input {
  border: none;
}
.webix_toolbar.webix_layout_subbar {
  background: #ffffff;
}
.webix_toolbar.webix_layout_subbar .webix_el_label,
.webix_toolbar.webix_layout_subbar .webix_inp_label {
  font-size: 13px;
}
.webix_toolbar.webix_layout_subbar .webix_el_button {
  color: #555555 !important;
}
.webix_toolbar.webix_layout_subbar .webix_el_button input,
.webix_toolbar.webix_layout_subbar .webix_el_toggle input {
  border: none;
}
.webix_toolbar .webix_layout_toolbar,
.webix_toolbar .webix_layout_line,
.webix_toolbar .webix_layout_clean {
  background: transparent;
}
.webix_hidden_upload,
.webix_el_button .webix_hidden_upload {
  height: 1px;
  width: 1px;
  border: 0 !important;
  font-size: 1px;
  position: absolute;
  top: 0px;
  left: 0px;
  z-index: -1;
}
.webix_upload_client,
.webix_upload_error,
.webix_upload_server {
  width: 60px;
  text-align: center;
  float: right;
}
.error_icon,
.cancel_icon {
  display: inline-block;
  background-repeat: no-repeat;
}
.error_icon {
  width: 18px;
  height: 16px;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAAQCAYAAAAbBi9cAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyBpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuMC1jMDYwIDYxLjEzNDc3NywgMjAxMC8wMi8xMi0xNzozMjowMCAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENTNSBXaW5kb3dzIiB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAuaWlkOjZFMDdENjlDNjE2QzExRTI5QzhBQUU2OUI3RDY4RTFCIiB4bXBNTTpEb2N1bWVudElEPSJ4bXAuZGlkOjZFMDdENjlENjE2QzExRTI5QzhBQUU2OUI3RDY4RTFCIj4gPHhtcE1NOkRlcml2ZWRGcm9tIHN0UmVmOmluc3RhbmNlSUQ9InhtcC5paWQ6NkUwN0Q2OUE2MTZDMTFFMjlDOEFBRTY5QjdENjhFMUIiIHN0UmVmOmRvY3VtZW50SUQ9InhtcC5kaWQ6NkUwN0Q2OUI2MTZDMTFFMjlDOEFBRTY5QjdENjhFMUIiLz4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJERj4gPC94OnhtcG1ldGE+IDw/eHBhY2tldCBlbmQ9InIiPz4ZJnE7AAABdklEQVR42mK80aLPgAcwA/EcIOYB4mgg/oWuQL36AphmYcAPYvl5WBOYmBgY3n/6fQTIn4hLIRMeQ0CuaBHgY2EQ4GMF8euAWIgcg6qF+NmkOdiZGdhYmRiEBdhAhrSQapAKEBcJC7DCBUQE2UBUGhAbkGLQBDEhdjYmJkaGtHVMDD4LmBk+/2RgEBdhBwX+ZGINcuLiZPYW5Ie45tknRrAhIFqAl5WBh4vFBijsR8ggkI29IA0wwMsOo/+DaWjA9wIxGz6D0oAKDXi5EalCkvc/2DApPgifm5OZQZCPFRyGuAwCxwqya0AAZADMVTAgyA92TDUQS2MzqAUUxcAgRjPoP9hVyICVhREUi6B01g4TY4RmES0gvqSuyMPMQAK4ef/LXyBlAswmF2DWd4kJs2M1pGgLIvrRAXJyAIWqNzcXi7cgHysDqQAUnt9//LW52WoQBfLaDRlxDnWgYQzkAKBBDI+ef38E0n3nycsf6gyUgUcAAQYA9DZJKVXGocQAAAAASUVORK5CYII=);
}
.webix_upload_server {
  color: green;
}
.webix_remove_upload {
  float: right;
}
.cancel_icon {
  margin-top: 7px;
  width: 14px;
  height: 14px;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA4AAAAOCAQAAAC1QeVaAAAAsElEQVR4XoVQUQbDQBScAywIuUcpKCWglBJCDlBKf0vpbymhd5mDhIDcoAcoJQSEsn2G5KmWzMDsPG92ZyGAgVfWfBtrUwEOZnwwOu2UjaPCbScLAEzYmzxyxafMgaUlRXMTsJJ1B7jgy0Y7gHt5FdgyimeAS+a6ZpDTQkLkCQbmk9OBHaPv+p6x99jLFFuOsTMPSlXl8FVlrSopFBP/sIQAbn6+bwsHA29sNGhMBQgf1cri4JYEbDkAAAAASUVORK5CYII=);
}
.webix_upload_flash {
  width: 100%;
  height: 100%;
  position: absolute;
  bottom: 0;
  left: 0;
  background: #fff;
  filter: progid:DXImageTransform.Microsoft.Alpha(opacity=0);
}
.webix_drop_file {
  background: #CBE8F5;
  position: relative;
}
.webix_drop_file::before {
  content: "Drop files here";
  position: absolute;
  bottom: 10px;
  left: 0px;
  width: 100%;
  text-align: center;
}
.webix_fieldset fieldset {
  border: 1px solid #afafaf;
  margin: 0px;
  padding: 5px 8px;
}
.webix_fieldset legend {
  color: #555555;
  font-size: 12px;
}
.webix_slider_box {
  position: relative;
  padding: 0px 10px;
  height: 100%;
  padding-top: 9px;
  float: left;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_slider_box .webix_slider_left {
  height: 10px;
  float: left;
  width: 100px;
  background: #ffffff;
  border: 1px solid #d5d5d5;
  -webkit-border-top-left-radius: 5px;
  -webkit-border-bottom-left-radius: 5px;
  -webkit-border-top-right-radius: 0;
  -webkit-border-bottom-right-radius: 0;
  -moz-border-radius-topleft: 5px;
  -moz-border-radius-bottomleft: 5px;
  -moz-border-radius-topright: 0;
  -moz-border-radius-bottomright: 0;
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_slider_box .webix_slider_right {
  height: 10px;
  float: left;
  width: 100px;
  background: #fff;
  -webkit-border-top-left-radius: 0;
  -webkit-border-bottom-left-radius: 0;
  -webkit-border-top-right-radius: 5px;
  -webkit-border-bottom-right-radius: 5px;
  -moz-border-radius-topleft: 0;
  -moz-border-radius-bottomleft: 0;
  -moz-border-radius-topright: 5px;
  -moz-border-radius-bottomright: 5px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-top-right-radius: 5px;
  border-bottom-right-radius: 5px;
  border: 1px solid #d5d5d5;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.webix_slider_box .webix_slider_handle {
  z-index: 1px;
  position: absolute;
  width: 15px;
  height: 15px;
  top: 5px;
  border-radius: 8px;
}
.webix_slider_box .webix_slider_left {
  background-color: #ebebeb;
  border-color: #ebebeb !important;
}
.webix_slider_box .webix_slider_right {
  border-color: #ebebeb !important;
  background: #fff;
}
.webix_slider_box .webix_slider_handle {
  width: 17px;
  height: 17px;
  background: #3389ff;
}
.webix_rangeslider .webix_slider_box .webix_slider_left {
  position: absolute;
}
.webix_rangeslider .webix_slider_box .webix_slider_active {
  z-index: 1;
}
.webix_rangeslider .webix_slider_box .webix_slider_right {
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.webix_slider_alt .webix_slider_box .webix_slider_left {
  border: 1px solid #e1e1e1;
}
.webix_slider_alt .webix_slider_box .webix_slider_right {
  border: 1px solid #e1e1e1;
}
.webix_slider_alt .webix_slider_box .webix_slider_handle {
  width: 11px;
  margin: 0 2px;
  height: 20px;
  top: 2.5px;
  border-radius: 2px;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAICAYAAAAx8TU7AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuMy1jMDExIDY2LjE0NTY2MSwgMjAxMi8wMi8wNi0xNDo1NjoyNyAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENTNiAoV2luZG93cykiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6OTJCMjdFNENBRTg4MTFFMjk2NjJGMTJENjkyNDA2NTkiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6OTJCMjdFNERBRTg4MTFFMjk2NjJGMTJENjkyNDA2NTkiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDo5MkIyN0U0QUFFODgxMUUyOTY2MkYxMkQ2OTI0MDY1OSIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo5MkIyN0U0QkFFODgxMUUyOTY2MkYxMkQ2OTI0MDY1OSIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/Powz/icAAAAaSURBVHjaYmBgYDBjgAA4zcSABQysIECAAQBn+ACx2PqtbAAAAABJRU5ErkJggg==);
  background-repeat: no-repeat;
  background-position: 3px center;
}
.webix_slider_alt .webix_slider_box .webix_slider_left {
  background-color: #ebebeb;
  border-color: #ebebeb !important;
}
.webix_slider_alt .webix_slider_box .webix_slider_right {
  border-color: #ebebeb !important;
}
.webix_slider_alt .webix_slider_box .webix_slider_handle {
  box-shadow: 0px 5px 3px #f6f6f6 inset;
  background-color: #f6f6f6;
  border: 1px solid #c8c8c8;
}
.webix_slider_title {
  margin-bottom: -11px;
  text-align: center;
}
.webix_progress_top,
.webix_progress_bottom {
  width: 100%;
  position: absolute;
  top: 0px;
  left: 0px;
  height: 6px;
  overflow: hidden;
  z-index: 20;
  background: #f2f2f2;
}
.webix_progress_bottom {
  bottom: 0px;
  top: auto;
  height: 17px;
}
.webix_progress_top .webix_progress_state,
.webix_progress_bottom .webix_progress_state {
  width: 0px;
  height: 6px;
  background: #fea223;
  -moz-transition: width 3s;
  transition: width 3s;
}
.webix_progress_bottom .webix_progress_state {
  height: 17px;
}
.webix_progress_icon {
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0px;
  left: 0px;
  z-index: 20;
}
.webix_progress_icon .webix_progress_state {
  font-family: FontAwesome;
  font-size: 50px;
  position: absolute;
  left: 50%;
  top: 50%;
  margin-left: -25px;
  margin-top: -25px;
  display: inline-block;
  color: #a2a2a2;
}
.webix_organogram canvas {
  position: absolute;
}
.webix_organogram_item {
  position: absolute;
  z-index: 1;
  font-family: "PT Sans", Tahoma;
  font-size: 15px;
  text-align: center;
  border-radius: 4px;
  background-color: #e3f2fd;
  border: 1px solid #bbdefb;
  padding: 7px 7px 10px 7px;
  box-sizing: border-box;
}
.webix_organogram_item.webix_selected {
  background-color: #fea223;
  border-color: #fea223;
}
.webix_organogram_list {
  border-radius: 4px;
  position: absolute;
  z-index: 1;
  height: auto;
  border: 1px solid #dddddd;
  box-sizing: border-box;
}
.webix_organogram_list_item {
  font-family: "PT Sans", Tahoma;
  border: none;
  text-align: left;
  position: static;
  padding: 5px;
  border-radius: 0px;
}
/*!
 *  Font Awesome 4.3.0 by @davegandy - http://fontawesome.io - @fontawesome
 *  License - http://fontawesome.io/license (Font: SIL OFL 1.1, CSS: MIT License)
 */
/* FONT PATH
 * -------------------------- */
@font-face {
  font-family: 'FontAwesome';
  src: url('../../fonts/fontawesome-webfont.eot?v=4.3.0');
  src: url('../../fonts/fontawesome-webfont.eot?#iefix&v=4.3.0') format('embedded-opentype'), url('../../fonts/fontawesome-webfont.woff?v=4.3.0') format('woff'), url('../../fonts/fontawesome-webfont.ttf?v=4.3.0') format('truetype'), url('../../fonts/fontawesome-webfont.svg?v=4.3.0#fontawesomeregular') format('svg');
  font-weight: normal;
  font-style: normal;
}
.webix_icon,
.webix_icon_btn,
.webix_input_icon,
.fa {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  transform: translate(0, 0);
}
/* makes the font 33% larger relative to the icon container */
.fa-lg {
  font-size: 1.33333333em;
  line-height: 0.75em;
  vertical-align: -15%;
}
.fa-2x {
  font-size: 2em;
}
.fa-3x {
  font-size: 3em;
}
.fa-4x {
  font-size: 4em;
}
.fa-5x {
  font-size: 5em;
}
.fa-fw {
  width: 1.28571429em;
  text-align: center;
}
.fa-ul {
  padding-left: 0;
  margin-left: 2.14285714em;
  list-style-type: none;
}
.fa-ul > li {
  position: relative;
}
.fa-li {
  position: absolute;
  left: -2.14285714em;
  width: 2.14285714em;
  top: 0.14285714em;
  text-align: center;
}
.fa-li.fa-lg {
  left: -1.85714286em;
}
.fa-border {
  padding: .2em .25em .15em;
  border: solid 0.08em #eeeeee;
  border-radius: .1em;
}
.pull-right {
  float: right;
}
.pull-left {
  float: left;
}
.fa.pull-left {
  margin-right: .3em;
}
.fa.pull-right {
  margin-left: .3em;
}
.fa-spin {
  -webkit-animation: fa-spin 2s infinite linear;
  animation: fa-spin 2s infinite linear;
}
.fa-pulse {
  -webkit-animation: fa-spin 1s infinite steps(8);
  animation: fa-spin 1s infinite steps(8);
}
@-webkit-keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
.fa-rotate-90 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
}
.fa-rotate-180 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
.fa-rotate-270 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3);
  -webkit-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  transform: rotate(270deg);
}
.fa-flip-horizontal {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1);
  -webkit-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  transform: scale(-1, 1);
}
.fa-flip-vertical {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1);
  -webkit-transform: scale(1, -1);
  -ms-transform: scale(1, -1);
  transform: scale(1, -1);
}
:root .fa-rotate-90,
:root .fa-rotate-180,
:root .fa-rotate-270,
:root .fa-flip-horizontal,
:root .fa-flip-vertical {
  filter: none;
}
.fa-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: middle;
}
.fa-stack-1x,
.fa-stack-2x {
  position: absolute;
  left: 0;
  width: 100%;
  text-align: center;
}
.fa-stack-1x {
  line-height: inherit;
}
.fa-stack-2x {
  font-size: 2em;
}
.fa-inverse {
  color: #ffffff;
}
/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */
.fa-glass:before {
  content: "\f000";
}
.fa-music:before {
  content: "\f001";
}
.fa-search:before {
  content: "\f002";
}
.fa-envelope-o:before {
  content: "\f003";
}
.fa-heart:before {
  content: "\f004";
}
.fa-star:before {
  content: "\f005";
}
.fa-star-o:before {
  content: "\f006";
}
.fa-user:before {
  content: "\f007";
}
.fa-film:before {
  content: "\f008";
}
.fa-th-large:before {
  content: "\f009";
}
.fa-th:before {
  content: "\f00a";
}
.fa-th-list:before {
  content: "\f00b";
}
.fa-check:before {
  content: "\f00c";
}
.fa-remove:before,
.fa-close:before,
.fa-times:before {
  content: "\f00d";
}
.fa-search-plus:before {
  content: "\f00e";
}
.fa-search-minus:before {
  content: "\f010";
}
.fa-power-off:before {
  content: "\f011";
}
.fa-signal:before {
  content: "\f012";
}
.fa-gear:before,
.fa-cog:before {
  content: "\f013";
}
.fa-trash-o:before {
  content: "\f014";
}
.fa-home:before {
  content: "\f015";
}
.fa-file-o:before {
  content: "\f016";
}
.fa-clock-o:before {
  content: "\f017";
}
.fa-road:before {
  content: "\f018";
}
.fa-download:before {
  content: "\f019";
}
.fa-arrow-circle-o-down:before {
  content: "\f01a";
}
.fa-arrow-circle-o-up:before {
  content: "\f01b";
}
.fa-inbox:before {
  content: "\f01c";
}
.fa-play-circle-o:before {
  content: "\f01d";
}
.fa-rotate-right:before,
.fa-repeat:before {
  content: "\f01e";
}
.fa-refresh:before {
  content: "\f021";
}
.fa-list-alt:before {
  content: "\f022";
}
.fa-lock:before {
  content: "\f023";
}
.fa-flag:before {
  content: "\f024";
}
.fa-headphones:before {
  content: "\f025";
}
.fa-volume-off:before {
  content: "\f026";
}
.fa-volume-down:before {
  content: "\f027";
}
.fa-volume-up:before {
  content: "\f028";
}
.fa-qrcode:before {
  content: "\f029";
}
.fa-barcode:before {
  content: "\f02a";
}
.fa-tag:before {
  content: "\f02b";
}
.fa-tags:before {
  content: "\f02c";
}
.fa-book:before {
  content: "\f02d";
}
.fa-bookmark:before {
  content: "\f02e";
}
.fa-print:before {
  content: "\f02f";
}
.fa-camera:before {
  content: "\f030";
}
.fa-font:before {
  content: "\f031";
}
.fa-bold:before {
  content: "\f032";
}
.fa-italic:before {
  content: "\f033";
}
.fa-text-height:before {
  content: "\f034";
}
.fa-text-width:before {
  content: "\f035";
}
.fa-align-left:before {
  content: "\f036";
}
.fa-align-center:before {
  content: "\f037";
}
.fa-align-right:before {
  content: "\f038";
}
.fa-align-justify:before {
  content: "\f039";
}
.fa-list:before {
  content: "\f03a";
}
.fa-dedent:before,
.fa-outdent:before {
  content: "\f03b";
}
.fa-indent:before {
  content: "\f03c";
}
.fa-video-camera:before {
  content: "\f03d";
}
.fa-photo:before,
.fa-image:before,
.fa-picture-o:before {
  content: "\f03e";
}
.fa-pencil:before {
  content: "\f040";
}
.fa-map-marker:before {
  content: "\f041";
}
.fa-adjust:before {
  content: "\f042";
}
.fa-tint:before {
  content: "\f043";
}
.fa-edit:before,
.fa-pencil-square-o:before {
  content: "\f044";
}
.fa-share-square-o:before {
  content: "\f045";
}
.fa-check-square-o:before {
  content: "\f046";
}
.fa-arrows:before {
  content: "\f047";
}
.fa-step-backward:before {
  content: "\f048";
}
.fa-fast-backward:before {
  content: "\f049";
}
.fa-backward:before {
  content: "\f04a";
}
.fa-play:before {
  content: "\f04b";
}
.fa-pause:before {
  content: "\f04c";
}
.fa-stop:before {
  content: "\f04d";
}
.fa-forward:before {
  content: "\f04e";
}
.fa-fast-forward:before {
  content: "\f050";
}
.fa-step-forward:before {
  content: "\f051";
}
.fa-eject:before {
  content: "\f052";
}
.fa-chevron-left:before {
  content: "\f053";
}
.fa-chevron-right:before {
  content: "\f054";
}
.fa-plus-circle:before {
  content: "\f055";
}
.fa-minus-circle:before {
  content: "\f056";
}
.fa-times-circle:before {
  content: "\f057";
}
.fa-check-circle:before {
  content: "\f058";
}
.fa-question-circle:before {
  content: "\f059";
}
.fa-info-circle:before {
  content: "\f05a";
}
.fa-crosshairs:before {
  content: "\f05b";
}
.fa-times-circle-o:before {
  content: "\f05c";
}
.fa-check-circle-o:before {
  content: "\f05d";
}
.fa-ban:before {
  content: "\f05e";
}
.fa-arrow-left:before {
  content: "\f060";
}
.fa-arrow-right:before {
  content: "\f061";
}
.fa-arrow-up:before {
  content: "\f062";
}
.fa-arrow-down:before {
  content: "\f063";
}
.fa-mail-forward:before,
.fa-share:before {
  content: "\f064";
}
.fa-expand:before {
  content: "\f065";
}
.fa-compress:before {
  content: "\f066";
}
.fa-plus:before {
  content: "\f067";
}
.fa-minus:before {
  content: "\f068";
}
.fa-asterisk:before {
  content: "\f069";
}
.fa-exclamation-circle:before {
  content: "\f06a";
}
.fa-gift:before {
  content: "\f06b";
}
.fa-leaf:before {
  content: "\f06c";
}
.fa-fire:before {
  content: "\f06d";
}
.fa-eye:before {
  content: "\f06e";
}
.fa-eye-slash:before {
  content: "\f070";
}
.fa-warning:before,
.fa-exclamation-triangle:before {
  content: "\f071";
}
.fa-plane:before {
  content: "\f072";
}
.fa-calendar:before {
  content: "\f073";
}
.fa-random:before {
  content: "\f074";
}
.fa-comment:before {
  content: "\f075";
}
.fa-magnet:before {
  content: "\f076";
}
.fa-chevron-up:before {
  content: "\f077";
}
.fa-chevron-down:before {
  content: "\f078";
}
.fa-retweet:before {
  content: "\f079";
}
.fa-shopping-cart:before {
  content: "\f07a";
}
.fa-folder:before {
  content: "\f07b";
}
.fa-folder-open:before {
  content: "\f07c";
}
.fa-arrows-v:before {
  content: "\f07d";
}
.fa-arrows-h:before {
  content: "\f07e";
}
.fa-bar-chart-o:before,
.fa-bar-chart:before {
  content: "\f080";
}
.fa-twitter-square:before {
  content: "\f081";
}
.fa-facebook-square:before {
  content: "\f082";
}
.fa-camera-retro:before {
  content: "\f083";
}
.fa-key:before {
  content: "\f084";
}
.fa-gears:before,
.fa-cogs:before {
  content: "\f085";
}
.fa-comments:before {
  content: "\f086";
}
.fa-thumbs-o-up:before {
  content: "\f087";
}
.fa-thumbs-o-down:before {
  content: "\f088";
}
.fa-star-half:before {
  content: "\f089";
}
.fa-heart-o:before {
  content: "\f08a";
}
.fa-sign-out:before {
  content: "\f08b";
}
.fa-linkedin-square:before {
  content: "\f08c";
}
.fa-thumb-tack:before {
  content: "\f08d";
}
.fa-external-link:before {
  content: "\f08e";
}
.fa-sign-in:before {
  content: "\f090";
}
.fa-trophy:before {
  content: "\f091";
}
.fa-github-square:before {
  content: "\f092";
}
.fa-upload:before {
  content: "\f093";
}
.fa-lemon-o:before {
  content: "\f094";
}
.fa-phone:before {
  content: "\f095";
}
.fa-square-o:before {
  content: "\f096";
}
.fa-bookmark-o:before {
  content: "\f097";
}
.fa-phone-square:before {
  content: "\f098";
}
.fa-twitter:before {
  content: "\f099";
}
.fa-facebook-f:before,
.fa-facebook:before {
  content: "\f09a";
}
.fa-github:before {
  content: "\f09b";
}
.fa-unlock:before {
  content: "\f09c";
}
.fa-credit-card:before {
  content: "\f09d";
}
.fa-rss:before {
  content: "\f09e";
}
.fa-hdd-o:before {
  content: "\f0a0";
}
.fa-bullhorn:before {
  content: "\f0a1";
}
.fa-bell:before {
  content: "\f0f3";
}
.fa-certificate:before {
  content: "\f0a3";
}
.fa-hand-o-right:before {
  content: "\f0a4";
}
.fa-hand-o-left:before {
  content: "\f0a5";
}
.fa-hand-o-up:before {
  content: "\f0a6";
}
.fa-hand-o-down:before {
  content: "\f0a7";
}
.fa-arrow-circle-left:before {
  content: "\f0a8";
}
.fa-arrow-circle-right:before {
  content: "\f0a9";
}
.fa-arrow-circle-up:before {
  content: "\f0aa";
}
.fa-arrow-circle-down:before {
  content: "\f0ab";
}
.fa-globe:before {
  content: "\f0ac";
}
.fa-wrench:before {
  content: "\f0ad";
}
.fa-tasks:before {
  content: "\f0ae";
}
.fa-filter:before {
  content: "\f0b0";
}
.fa-briefcase:before {
  content: "\f0b1";
}
.fa-arrows-alt:before {
  content: "\f0b2";
}
.fa-group:before,
.fa-users:before {
  content: "\f0c0";
}
.fa-chain:before,
.fa-link:before {
  content: "\f0c1";
}
.fa-cloud:before {
  content: "\f0c2";
}
.fa-flask:before {
  content: "\f0c3";
}
.fa-cut:before,
.fa-scissors:before {
  content: "\f0c4";
}
.fa-copy:before,
.fa-files-o:before {
  content: "\f0c5";
}
.fa-paperclip:before {
  content: "\f0c6";
}
.fa-save:before,
.fa-floppy-o:before {
  content: "\f0c7";
}
.fa-square:before {
  content: "\f0c8";
}
.fa-navicon:before,
.fa-reorder:before,
.fa-bars:before {
  content: "\f0c9";
}
.fa-list-ul:before {
  content: "\f0ca";
}
.fa-list-ol:before {
  content: "\f0cb";
}
.fa-strikethrough:before {
  content: "\f0cc";
}
.fa-underline:before {
  content: "\f0cd";
}
.fa-table:before {
  content: "\f0ce";
}
.fa-magic:before {
  content: "\f0d0";
}
.fa-truck:before {
  content: "\f0d1";
}
.fa-pinterest:before {
  content: "\f0d2";
}
.fa-pinterest-square:before {
  content: "\f0d3";
}
.fa-google-plus-square:before {
  content: "\f0d4";
}
.fa-google-plus:before {
  content: "\f0d5";
}
.fa-money:before {
  content: "\f0d6";
}
.fa-caret-down:before {
  content: "\f0d7";
}
.fa-caret-up:before {
  content: "\f0d8";
}
.fa-caret-left:before {
  content: "\f0d9";
}
.fa-caret-right:before {
  content: "\f0da";
}
.fa-columns:before {
  content: "\f0db";
}
.fa-unsorted:before,
.fa-sort:before {
  content: "\f0dc";
}
.fa-sort-down:before,
.fa-sort-desc:before {
  content: "\f0dd";
}
.fa-sort-up:before,
.fa-sort-asc:before {
  content: "\f0de";
}
.fa-envelope:before {
  content: "\f0e0";
}
.fa-linkedin:before {
  content: "\f0e1";
}
.fa-rotate-left:before,
.fa-undo:before {
  content: "\f0e2";
}
.fa-legal:before,
.fa-gavel:before {
  content: "\f0e3";
}
.fa-dashboard:before,
.fa-tachometer:before {
  content: "\f0e4";
}
.fa-comment-o:before {
  content: "\f0e5";
}
.fa-comments-o:before {
  content: "\f0e6";
}
.fa-flash:before,
.fa-bolt:before {
  content: "\f0e7";
}
.fa-sitemap:before {
  content: "\f0e8";
}
.fa-umbrella:before {
  content: "\f0e9";
}
.fa-paste:before,
.fa-clipboard:before {
  content: "\f0ea";
}
.fa-lightbulb-o:before {
  content: "\f0eb";
}
.fa-exchange:before {
  content: "\f0ec";
}
.fa-cloud-download:before {
  content: "\f0ed";
}
.fa-cloud-upload:before {
  content: "\f0ee";
}
.fa-user-md:before {
  content: "\f0f0";
}
.fa-stethoscope:before {
  content: "\f0f1";
}
.fa-suitcase:before {
  content: "\f0f2";
}
.fa-bell-o:before {
  content: "\f0a2";
}
.fa-coffee:before {
  content: "\f0f4";
}
.fa-cutlery:before {
  content: "\f0f5";
}
.fa-file-text-o:before {
  content: "\f0f6";
}
.fa-building-o:before {
  content: "\f0f7";
}
.fa-hospital-o:before {
  content: "\f0f8";
}
.fa-ambulance:before {
  content: "\f0f9";
}
.fa-medkit:before {
  content: "\f0fa";
}
.fa-fighter-jet:before {
  content: "\f0fb";
}
.fa-beer:before {
  content: "\f0fc";
}
.fa-h-square:before {
  content: "\f0fd";
}
.fa-plus-square:before {
  content: "\f0fe";
}
.fa-angle-double-left:before {
  content: "\f100";
}
.fa-angle-double-right:before {
  content: "\f101";
}
.fa-angle-double-up:before {
  content: "\f102";
}
.fa-angle-double-down:before {
  content: "\f103";
}
.fa-angle-left:before {
  content: "\f104";
}
.fa-angle-right:before {
  content: "\f105";
}
.fa-angle-up:before {
  content: "\f106";
}
.fa-angle-down:before {
  content: "\f107";
}
.fa-desktop:before {
  content: "\f108";
}
.fa-laptop:before {
  content: "\f109";
}
.fa-tablet:before {
  content: "\f10a";
}
.fa-mobile-phone:before,
.fa-mobile:before {
  content: "\f10b";
}
.fa-circle-o:before {
  content: "\f10c";
}
.fa-quote-left:before {
  content: "\f10d";
}
.fa-quote-right:before {
  content: "\f10e";
}
.fa-spinner:before {
  content: "\f110";
}
.fa-circle:before {
  content: "\f111";
}
.fa-mail-reply:before,
.fa-reply:before {
  content: "\f112";
}
.fa-github-alt:before {
  content: "\f113";
}
.fa-folder-o:before {
  content: "\f114";
}
.fa-folder-open-o:before {
  content: "\f115";
}
.fa-smile-o:before {
  content: "\f118";
}
.fa-frown-o:before {
  content: "\f119";
}
.fa-meh-o:before {
  content: "\f11a";
}
.fa-gamepad:before {
  content: "\f11b";
}
.fa-keyboard-o:before {
  content: "\f11c";
}
.fa-flag-o:before {
  content: "\f11d";
}
.fa-flag-checkered:before {
  content: "\f11e";
}
.fa-terminal:before {
  content: "\f120";
}
.fa-code:before {
  content: "\f121";
}
.fa-mail-reply-all:before,
.fa-reply-all:before {
  content: "\f122";
}
.fa-star-half-empty:before,
.fa-star-half-full:before,
.fa-star-half-o:before {
  content: "\f123";
}
.fa-location-arrow:before {
  content: "\f124";
}
.fa-crop:before {
  content: "\f125";
}
.fa-code-fork:before {
  content: "\f126";
}
.fa-unlink:before,
.fa-chain-broken:before {
  content: "\f127";
}
.fa-question:before {
  content: "\f128";
}
.fa-info:before {
  content: "\f129";
}
.fa-exclamation:before {
  content: "\f12a";
}
.fa-superscript:before {
  content: "\f12b";
}
.fa-subscript:before {
  content: "\f12c";
}
.fa-eraser:before {
  content: "\f12d";
}
.fa-puzzle-piece:before {
  content: "\f12e";
}
.fa-microphone:before {
  content: "\f130";
}
.fa-microphone-slash:before {
  content: "\f131";
}
.fa-shield:before {
  content: "\f132";
}
.fa-calendar-o:before {
  content: "\f133";
}
.fa-fire-extinguisher:before {
  content: "\f134";
}
.fa-rocket:before {
  content: "\f135";
}
.fa-maxcdn:before {
  content: "\f136";
}
.fa-chevron-circle-left:before {
  content: "\f137";
}
.fa-chevron-circle-right:before {
  content: "\f138";
}
.fa-chevron-circle-up:before {
  content: "\f139";
}
.fa-chevron-circle-down:before {
  content: "\f13a";
}
.fa-html5:before {
  content: "\f13b";
}
.fa-css3:before {
  content: "\f13c";
}
.fa-anchor:before {
  content: "\f13d";
}
.fa-unlock-alt:before {
  content: "\f13e";
}
.fa-bullseye:before {
  content: "\f140";
}
.fa-ellipsis-h:before {
  content: "\f141";
}
.fa-ellipsis-v:before {
  content: "\f142";
}
.fa-rss-square:before {
  content: "\f143";
}
.fa-play-circle:before {
  content: "\f144";
}
.fa-ticket:before {
  content: "\f145";
}
.fa-minus-square:before {
  content: "\f146";
}
.fa-minus-square-o:before {
  content: "\f147";
}
.fa-level-up:before {
  content: "\f148";
}
.fa-level-down:before {
  content: "\f149";
}
.fa-check-square:before {
  content: "\f14a";
}
.fa-pencil-square:before {
  content: "\f14b";
}
.fa-external-link-square:before {
  content: "\f14c";
}
.fa-share-square:before {
  content: "\f14d";
}
.fa-compass:before {
  content: "\f14e";
}
.fa-toggle-down:before,
.fa-caret-square-o-down:before {
  content: "\f150";
}
.fa-toggle-up:before,
.fa-caret-square-o-up:before {
  content: "\f151";
}
.fa-toggle-right:before,
.fa-caret-square-o-right:before {
  content: "\f152";
}
.fa-euro:before,
.fa-eur:before {
  content: "\f153";
}
.fa-gbp:before {
  content: "\f154";
}
.fa-dollar:before,
.fa-usd:before {
  content: "\f155";
}
.fa-rupee:before,
.fa-inr:before {
  content: "\f156";
}
.fa-cny:before,
.fa-rmb:before,
.fa-yen:before,
.fa-jpy:before {
  content: "\f157";
}
.fa-ruble:before,
.fa-rouble:before,
.fa-rub:before {
  content: "\f158";
}
.fa-won:before,
.fa-krw:before {
  content: "\f159";
}
.fa-bitcoin:before,
.fa-btc:before {
  content: "\f15a";
}
.fa-file:before {
  content: "\f15b";
}
.fa-file-text:before {
  content: "\f15c";
}
.fa-sort-alpha-asc:before {
  content: "\f15d";
}
.fa-sort-alpha-desc:before {
  content: "\f15e";
}
.fa-sort-amount-asc:before {
  content: "\f160";
}
.fa-sort-amount-desc:before {
  content: "\f161";
}
.fa-sort-numeric-asc:before {
  content: "\f162";
}
.fa-sort-numeric-desc:before {
  content: "\f163";
}
.fa-thumbs-up:before {
  content: "\f164";
}
.fa-thumbs-down:before {
  content: "\f165";
}
.fa-youtube-square:before {
  content: "\f166";
}
.fa-youtube:before {
  content: "\f167";
}
.fa-xing:before {
  content: "\f168";
}
.fa-xing-square:before {
  content: "\f169";
}
.fa-youtube-play:before {
  content: "\f16a";
}
.fa-dropbox:before {
  content: "\f16b";
}
.fa-stack-overflow:before {
  content: "\f16c";
}
.fa-instagram:before {
  content: "\f16d";
}
.fa-flickr:before {
  content: "\f16e";
}
.fa-adn:before {
  content: "\f170";
}
.fa-bitbucket:before {
  content: "\f171";
}
.fa-bitbucket-square:before {
  content: "\f172";
}
.fa-tumblr:before {
  content: "\f173";
}
.fa-tumblr-square:before {
  content: "\f174";
}
.fa-long-arrow-down:before {
  content: "\f175";
}
.fa-long-arrow-up:before {
  content: "\f176";
}
.fa-long-arrow-left:before {
  content: "\f177";
}
.fa-long-arrow-right:before {
  content: "\f178";
}
.fa-apple:before {
  content: "\f179";
}
.fa-windows:before {
  content: "\f17a";
}
.fa-android:before {
  content: "\f17b";
}
.fa-linux:before {
  content: "\f17c";
}
.fa-dribbble:before {
  content: "\f17d";
}
.fa-skype:before {
  content: "\f17e";
}
.fa-foursquare:before {
  content: "\f180";
}
.fa-trello:before {
  content: "\f181";
}
.fa-female:before {
  content: "\f182";
}
.fa-male:before {
  content: "\f183";
}
.fa-gittip:before,
.fa-gratipay:before {
  content: "\f184";
}
.fa-sun-o:before {
  content: "\f185";
}
.fa-moon-o:before {
  content: "\f186";
}
.fa-archive:before {
  content: "\f187";
}
.fa-bug:before {
  content: "\f188";
}
.fa-vk:before {
  content: "\f189";
}
.fa-weibo:before {
  content: "\f18a";
}
.fa-renren:before {
  content: "\f18b";
}
.fa-pagelines:before {
  content: "\f18c";
}
.fa-stack-exchange:before {
  content: "\f18d";
}
.fa-arrow-circle-o-right:before {
  content: "\f18e";
}
.fa-arrow-circle-o-left:before {
  content: "\f190";
}
.fa-toggle-left:before,
.fa-caret-square-o-left:before {
  content: "\f191";
}
.fa-dot-circle-o:before {
  content: "\f192";
}
.fa-wheelchair:before {
  content: "\f193";
}
.fa-vimeo-square:before {
  content: "\f194";
}
.fa-turkish-lira:before,
.fa-try:before {
  content: "\f195";
}
.fa-plus-square-o:before {
  content: "\f196";
}
.fa-space-shuttle:before {
  content: "\f197";
}
.fa-slack:before {
  content: "\f198";
}
.fa-envelope-square:before {
  content: "\f199";
}
.fa-wordpress:before {
  content: "\f19a";
}
.fa-openid:before {
  content: "\f19b";
}
.fa-institution:before,
.fa-bank:before,
.fa-university:before {
  content: "\f19c";
}
.fa-mortar-board:before,
.fa-graduation-cap:before {
  content: "\f19d";
}
.fa-yahoo:before {
  content: "\f19e";
}
.fa-google:before {
  content: "\f1a0";
}
.fa-reddit:before {
  content: "\f1a1";
}
.fa-reddit-square:before {
  content: "\f1a2";
}
.fa-stumbleupon-circle:before {
  content: "\f1a3";
}
.fa-stumbleupon:before {
  content: "\f1a4";
}
.fa-delicious:before {
  content: "\f1a5";
}
.fa-digg:before {
  content: "\f1a6";
}
.fa-pied-piper:before {
  content: "\f1a7";
}
.fa-pied-piper-alt:before {
  content: "\f1a8";
}
.fa-drupal:before {
  content: "\f1a9";
}
.fa-joomla:before {
  content: "\f1aa";
}
.fa-language:before {
  content: "\f1ab";
}
.fa-fax:before {
  content: "\f1ac";
}
.fa-building:before {
  content: "\f1ad";
}
.fa-child:before {
  content: "\f1ae";
}
.fa-paw:before {
  content: "\f1b0";
}
.fa-spoon:before {
  content: "\f1b1";
}
.fa-cube:before {
  content: "\f1b2";
}
.fa-cubes:before {
  content: "\f1b3";
}
.fa-behance:before {
  content: "\f1b4";
}
.fa-behance-square:before {
  content: "\f1b5";
}
.fa-steam:before {
  content: "\f1b6";
}
.fa-steam-square:before {
  content: "\f1b7";
}
.fa-recycle:before {
  content: "\f1b8";
}
.fa-automobile:before,
.fa-car:before {
  content: "\f1b9";
}
.fa-cab:before,
.fa-taxi:before {
  content: "\f1ba";
}
.fa-tree:before {
  content: "\f1bb";
}
.fa-spotify:before {
  content: "\f1bc";
}
.fa-deviantart:before {
  content: "\f1bd";
}
.fa-soundcloud:before {
  content: "\f1be";
}
.fa-database:before {
  content: "\f1c0";
}
.fa-file-pdf-o:before {
  content: "\f1c1";
}
.fa-file-word-o:before {
  content: "\f1c2";
}
.fa-file-excel-o:before {
  content: "\f1c3";
}
.fa-file-powerpoint-o:before {
  content: "\f1c4";
}
.fa-file-photo-o:before,
.fa-file-picture-o:before,
.fa-file-image-o:before {
  content: "\f1c5";
}
.fa-file-zip-o:before,
.fa-file-archive-o:before {
  content: "\f1c6";
}
.fa-file-sound-o:before,
.fa-file-audio-o:before {
  content: "\f1c7";
}
.fa-file-movie-o:before,
.fa-file-video-o:before {
  content: "\f1c8";
}
.fa-file-code-o:before {
  content: "\f1c9";
}
.fa-vine:before {
  content: "\f1ca";
}
.fa-codepen:before {
  content: "\f1cb";
}
.fa-jsfiddle:before {
  content: "\f1cc";
}
.fa-life-bouy:before,
.fa-life-buoy:before,
.fa-life-saver:before,
.fa-support:before,
.fa-life-ring:before {
  content: "\f1cd";
}
.fa-circle-o-notch:before {
  content: "\f1ce";
}
.fa-ra:before,
.fa-rebel:before {
  content: "\f1d0";
}
.fa-ge:before,
.fa-empire:before {
  content: "\f1d1";
}
.fa-git-square:before {
  content: "\f1d2";
}
.fa-git:before {
  content: "\f1d3";
}
.fa-hacker-news:before {
  content: "\f1d4";
}
.fa-tencent-weibo:before {
  content: "\f1d5";
}
.fa-qq:before {
  content: "\f1d6";
}
.fa-wechat:before,
.fa-weixin:before {
  content: "\f1d7";
}
.fa-send:before,
.fa-paper-plane:before {
  content: "\f1d8";
}
.fa-send-o:before,
.fa-paper-plane-o:before {
  content: "\f1d9";
}
.fa-history:before {
  content: "\f1da";
}
.fa-genderless:before,
.fa-circle-thin:before {
  content: "\f1db";
}
.fa-header:before {
  content: "\f1dc";
}
.fa-paragraph:before {
  content: "\f1dd";
}
.fa-sliders:before {
  content: "\f1de";
}
.fa-share-alt:before {
  content: "\f1e0";
}
.fa-share-alt-square:before {
  content: "\f1e1";
}
.fa-bomb:before {
  content: "\f1e2";
}
.fa-soccer-ball-o:before,
.fa-futbol-o:before {
  content: "\f1e3";
}
.fa-tty:before {
  content: "\f1e4";
}
.fa-binoculars:before {
  content: "\f1e5";
}
.fa-plug:before {
  content: "\f1e6";
}
.fa-slideshare:before {
  content: "\f1e7";
}
.fa-twitch:before {
  content: "\f1e8";
}
.fa-yelp:before {
  content: "\f1e9";
}
.fa-newspaper-o:before {
  content: "\f1ea";
}
.fa-wifi:before {
  content: "\f1eb";
}
.fa-calculator:before {
  content: "\f1ec";
}
.fa-paypal:before {
  content: "\f1ed";
}
.fa-google-wallet:before {
  content: "\f1ee";
}
.fa-cc-visa:before {
  content: "\f1f0";
}
.fa-cc-mastercard:before {
  content: "\f1f1";
}
.fa-cc-discover:before {
  content: "\f1f2";
}
.fa-cc-amex:before {
  content: "\f1f3";
}
.fa-cc-paypal:before {
  content: "\f1f4";
}
.fa-cc-stripe:before {
  content: "\f1f5";
}
.fa-bell-slash:before {
  content: "\f1f6";
}
.fa-bell-slash-o:before {
  content: "\f1f7";
}
.fa-trash:before {
  content: "\f1f8";
}
.fa-copyright:before {
  content: "\f1f9";
}
.fa-at:before {
  content: "\f1fa";
}
.fa-eyedropper:before {
  content: "\f1fb";
}
.fa-paint-brush:before {
  content: "\f1fc";
}
.fa-birthday-cake:before {
  content: "\f1fd";
}
.fa-area-chart:before {
  content: "\f1fe";
}
.fa-pie-chart:before {
  content: "\f200";
}
.fa-line-chart:before {
  content: "\f201";
}
.fa-lastfm:before {
  content: "\f202";
}
.fa-lastfm-square:before {
  content: "\f203";
}
.fa-toggle-off:before {
  content: "\f204";
}
.fa-toggle-on:before {
  content: "\f205";
}
.fa-bicycle:before {
  content: "\f206";
}
.fa-bus:before {
  content: "\f207";
}
.fa-ioxhost:before {
  content: "\f208";
}
.fa-angellist:before {
  content: "\f209";
}
.fa-cc:before {
  content: "\f20a";
}
.fa-shekel:before,
.fa-sheqel:before,
.fa-ils:before {
  content: "\f20b";
}
.fa-meanpath:before {
  content: "\f20c";
}
.fa-buysellads:before {
  content: "\f20d";
}
.fa-connectdevelop:before {
  content: "\f20e";
}
.fa-dashcube:before {
  content: "\f210";
}
.fa-forumbee:before {
  content: "\f211";
}
.fa-leanpub:before {
  content: "\f212";
}
.fa-sellsy:before {
  content: "\f213";
}
.fa-shirtsinbulk:before {
  content: "\f214";
}
.fa-simplybuilt:before {
  content: "\f215";
}
.fa-skyatlas:before {
  content: "\f216";
}
.fa-cart-plus:before {
  content: "\f217";
}
.fa-cart-arrow-down:before {
  content: "\f218";
}
.fa-diamond:before {
  content: "\f219";
}
.fa-ship:before {
  content: "\f21a";
}
.fa-user-secret:before {
  content: "\f21b";
}
.fa-motorcycle:before {
  content: "\f21c";
}
.fa-street-view:before {
  content: "\f21d";
}
.fa-heartbeat:before {
  content: "\f21e";
}
.fa-venus:before {
  content: "\f221";
}
.fa-mars:before {
  content: "\f222";
}
.fa-mercury:before {
  content: "\f223";
}
.fa-transgender:before {
  content: "\f224";
}
.fa-transgender-alt:before {
  content: "\f225";
}
.fa-venus-double:before {
  content: "\f226";
}
.fa-mars-double:before {
  content: "\f227";
}
.fa-venus-mars:before {
  content: "\f228";
}
.fa-mars-stroke:before {
  content: "\f229";
}
.fa-mars-stroke-v:before {
  content: "\f22a";
}
.fa-mars-stroke-h:before {
  content: "\f22b";
}
.fa-neuter:before {
  content: "\f22c";
}
.fa-facebook-official:before {
  content: "\f230";
}
.fa-pinterest-p:before {
  content: "\f231";
}
.fa-whatsapp:before {
  content: "\f232";
}
.fa-server:before {
  content: "\f233";
}
.fa-user-plus:before {
  content: "\f234";
}
.fa-user-times:before {
  content: "\f235";
}
.fa-hotel:before,
.fa-bed:before {
  content: "\f236";
}
.fa-viacoin:before {
  content: "\f237";
}
.fa-train:before {
  content: "\f238";
}
.fa-subway:before {
  content: "\f239";
}
.fa-medium:before {
  content: "\f23a";
}
.webix_icon,
.webix_input_icon {
  font-size: 17px;
  display: inline-block;
  width: 20px;
}
.webix_input_icon {
  float: right;
  font-size: 19px;
  color: #888;
}
.webix_icon_button {
  background-color: transparent;
  border: none;
  padding: 0;
  cursor: pointer;
  position: relative;
}
.webix_icon_button .webix_icon {
  font-size: 20px;
  height: 23px;
  width: 21px;
  display: inline-block;
  text-align: center;
  color: #606060;
}
.webix_icon_btn {
  font-size: 17px;
  display: inline-block;
  text-align: center;
  width: 24px;
  color: #606060;
}
.webix_el_iconBbutton .webix_icon_btn {
  text-align: center;
  width: 100%;
  padding: 5px 0px;
}
.webix_el_icon {
  cursor: pointer;
}
.webix_badge {
  background-color: #ff8839;
  color: #ffffff;
  border-radius: 50%;
  font-size: 12px;
  height: 22px;
  min-width: 22px;
  box-sizing: border-box;
  padding: 0 4px;
  text-align: center;
  line-height: 21px;
  position: absolute;
  right: 0;
  top: 0;
}
.webix_list_item .webix_badge {
  position: static;
  float: right;
  margin: 4px -5px 0 10px;
}
.webixtype_base .webix_badge {
  top: 50%;
  margin-top: -11px;
  margin-right: 8px;
}
.webix_barcode {
  position: relative;
}
.webix_barcode .webix_canvas_text {
  font-size: 13px;
  padding: 0 2px;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.portlet_drag {
  position: absolute;
  z-index: 1;
  top: 5px;
  right: 5px;
  width: 18px;
  opacity: 0.5;
  cursor: pointer;
}
.portlet_in_drag {
  opacity: 0.4;
}
.portlet_marker,
.portlet_markertop,
.portlet_markerbottom,
.portlet_markerleft,
.portlet_markerright {
  opacity: 0.5;
  background: #9169BE;
  position: absolute;
  transition: top 0.5s, left 0.5s, width 0.5s, height 0.5s;
  top: 0px;
  left: 0px;
  width: 100%;
  height: 100%;
}
.portlet_markertop {
  height: 50%;
}
.portlet_markerbottom {
  height: 50%;
  top: 50%;
}
.portlet_markerleft {
  width: 50%;
}
.portlet_markerright {
  width: 50%;
  left: 50%;
}
/*[L]*/
/*[L]*/
.webix_accordionitem.collapsed {
  color: #4d4d4d;
  background: #80b5ff;
}
.webix_layout_wide .webix_accordionitem.collapsed,
.webix_layout_space .webix_accordionitem.collapsed,
.webix_layout_accordion .webix_accordionitem.collapsed {
  border-color: #80b5ff !important;
}
.webix_accordionitem_header.collapsed {
  background: transparent;
}
.webix_accordionitem.vertical > .webix_accordionitem_header .webix_accordionitem_button {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAsAAAAHCAYAAADebrddAAAARUlEQVR42o2PAQYAMAwD9+iEFvTpnZYZU7EQRa4kaxKAXD9y9yTZluCBALRJpATNrIG6rAdjjmBVeCuB6EyAYkNEiDE33yMJRSaycR8/AAAAAElFTkSuQmCC);
  background-repeat: no-repeat;
}
.webix_accordionitem.vertical.collapsed > .webix_accordionitem_header .webix_accordionitem_button {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAsAAAAHCAYAAADebrddAAAASElEQVR42n2PMQoAMAgD++gEdPLpFkshS9oDEcxlcA1V1euNcpI9k5m2MPfrqABCBS8KBptAR8QJZks0kGjgjMQn/oc/AKy4Acp9RSZl+HEYAAAAAElFTkSuQmCC);
  background-repeat: no-repeat;
}
.webix_accordionitem.horizontal > .webix_accordionitem_header .webix_accordionitem_button {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAcAAAALCAYAAACzkJeoAAAASUlEQVR42p2QMQoAQQgD79EZ0Mqn5xCu2cPdYgUbJ0rMMxXgLeiuKq8gsJAz8weQ0QiwJEfECnr4wdlEnwJ68+yyhReC+c85oRecj0Um+pmo9wAAAABJRU5ErkJggg==);
  background-repeat: no-repeat;
}
.webix_accordionitem.horizontal:last-child > .webix_accordionitem_header .webix_accordionitem_button {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAcAAAALCAYAAACzkJeoAAAARElEQVR42qXPsQoAIAhF0T76PdDJT7cUmtQhcmk4N8QVQ9JXN2bmgWOgqp+BiCRG2AYAMoi3/LxYdyagAnhA6G93TrABZaJFJjrFY8IAAAAASUVORK5CYII=);
  background-repeat: no-repeat;
}
.webix_accordionitem.horizontal.collapsed:last-child > .webix_accordionitem_header .webix_accordionitem_button {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAsAAAAHCAYAAADebrddAAAASElEQVR42n2PMQoAMAgD++gEdPLpFkshS9oDEcxlcA1V1euNcpI9k5m2MPfrqABCBS8KBptAR8QJZks0kGjgjMQn/oc/AKy4Acp9RSZl+HEYAAAAAElFTkSuQmCC);
  background-repeat: no-repeat;
}
.webix_accordionitem.horizontal.collapsed > .webix_accordionitem_header .webix_accordionitem_button {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAsAAAAHCAYAAADebrddAAAARUlEQVR42o2PAQYAMAwD9+iEFvTpnZYZU7EQRa4kaxKAXD9y9yTZluCBALRJpATNrIG6rAdjjmBVeCuB6EyAYkNEiDE33yMJRSaycR8/AAAAAElFTkSuQmCC);
  background-repeat: no-repeat;
}
.webix_layout_toolbar.webix_layout_toolbar {
  background: #66a6ff;
}
.webix_toolbar .webix_el_button .webix_el_box,
.webix_toolbar .webix_el_segmented .webix_el_box {
  padding: 0 1px;
}
.webix_toolbar .webix_el_segmented label {
  padding-top: 2px;
}
.webix_toolbar .webix_view {
  color: #4d4d4d;
  font-size: 15px !important;
}
.webix_toolbar.webix_layout_toolbar .webix_img_btn_top,
.webix_toolbar.webix_layout_toolbar webix_el_icon,
.webix_toolbar.webix_layout_toolbar .webix_img_btn,
.webix_toolbar.webix_layout_toolbar .webix_icon_btn,
.webix_toolbar.webix_layout_toolbar .webix_icon_button {
  color: #4d4d4d;
}
.webix_toolbar.webix_layout_toolbar .webix_img_btn_abs,
.webix_toolbar.webix_layout_toolbar .webix_inp_static {
  color: #555555;
}
.webix_toolbar.webix_layout_toolbar .webix_inp_label {
  color: #4d4d4d;
}
.webix_toolbar.webix_layout_subbar {
  background: transparent;
}
.webix_toolbar.webix_layout_subbar .webix_view {
  color: #555555;
}
.webix_view .webix_win_head > .webix_view > .webix_template {
  color: #ffffff;
  font-size: 15px;
  background: #3d8fff;
}
.webix_modal_box .webix_popup_title {
  color: #555555 !important;
  background: #66a6ff;
  font-size: 15px;
  font-weight: bold;
  border-bottom: 1px solid #b8b8b8 !important;
  text-shadow: none !important;
}
.webix_modal_box .webix_popup_text {
  color: #555555;
}
.webix_modal_box {
  color: #555555;
  background: #fff !important;
  border: 1px solid #b8b8b8 !important;
}
.confirmButton {
  background: #006bff;
  border: 1px solid #006bff;
  font-size: 15px !important;
  text-shadow: none !important;
  color: #ffffff !important;
  border-color: #006bff !important;
}
.confirmButtonActive {
  background: #0d6df2;
}
.webix_popup_button {
  border: none !important;
}
.webix_dtable .webix_ss_right .webix_column.webix_first > div {
  border-left: 1px solid transparent;
}
.webix_dtable .webix_ss_left .webix_column.webix_last > div {
  border-right: 1px solid transparent;
}
.webix_dtable .webix_hs_right td.webix_first {
  border-left: 1px dashed #ffffff;
}
.webix_ss_sort_asc,
.webix_ss_sort_desc {
  font-size: 14px;
  font-family: FontAwesome;
  top: 50%;
  line-height: 1px;
  bottom: auto;
  float: none;
  width: 12px;
}
.webix_ss_sort_asc:before {
  content: '\f106';
}
.webix_ss_sort_desc:before {
  content: '\f107';
}
.webix_ss_header tr:nth-child(2) td {
  border-top: 1px solid transparent ;
}
.webix_inp_label,
.webix_inp_top_label,
.webix_label_right,
.webix_el_label {
  text-transform: none !important;
  font-size: 13px !important;
}
.webix_dtable .webix_ss_vscroll_header {
  border-bottom: 1px solid #c8c8c8;
  border-left: 1px solid #c8c8c8;
}
.webix_list_item.webix_group_back {
  background: #f1f1f1;
  color: #555555;
  border-bottom: 1px solid #ffffff;
}
.webix_list_item.webix_group_back .webix_arrow_icon {
  color: #555555;
}
.webix_list_item.webix_group_back:first-child {
  background: #c8c8c8;
}
.webix_menu.webix_view .webix_list_item.webix_selected {
  background-color: #fea223;
}
.webix_list_item .webix_submenu_icon {
  width: 0px;
  height: 0px;
  border-width: 4px;
  border-style: solid;
}
.webix_menu .webix_list_item .webix_submenu_icon {
  border-color: transparent transparent transparent #626262;
}
.webix_el_text input,
.webix_el_search input,
.webix_el_combo input,
.webix_el_select select,
div.webix_inp_static,
.webix_el_textarea textarea {
  font-family: Arial;
  font-size: 13px;
  color: #555555;
  background-color: #ebebeb;
  border-color: #ebebeb !important;
}
.webix_el_checkbox input {
  border-color: #c8c8c8;
}
.webix_el_counter .webix_inp_counter_value {
  background-color: #ebebeb;
  border-color: #ebebeb !important;
}
.webix_el_counter .webix_inp_counter_prev,
.webix_el_counter .webix_inp_counter_next {
  background: #3389ff;
  font-size: 15px !important;
  border: 1px solid #3389ff;
  width: 30px;
  font-family: "Courier New", Courier, monospace;
  color: #ffffff;
  font-size: 15px;
  border: 1px solid #3389ff !important;
}
.webix_el_counter .webix_inp_counter_prev {
  font-size: 18px;
}
.webix_el_counter .webix_inp_counter_next {
  font-size: 17px;
}
.webix_view.webix_control.webix_el_tabbar {
  background: transparent;
}
.webix_item_tab {
  font-size: 15px;
  border-bottom: 1px solid #c8c8c8 !important;
  border-left-width: 1px !important;
}
.webixtype_bottom .webix_item_tab {
  border: 1px solid #ffffff !important;
  border-left-width: 0 !important;
  background: #66a6ff;
  color: #555555;
}
.webix_el_tabbar .webixtype_bottom .webix_item_tab.webix_selected {
  border: 1px solid #ffffff !important;
  border-left-width: 0 !important;
  background: #006bff;
  color: #ffffff !important;
}
.webixtype_bottom .webix_item_tab:last-child {
  border-right: 0  !important;
}
.webix_tab_filler:first-child {
  border-right: 0 !important;
}
.passiveBarBG {
  background-color: #ebebeb;
}
.webix_after_all_tabs {
  background: #ffffff;
}
.webixtype_danger:active {
  background: #d16051 !important;
}
.webix_img_btn:active,
.webix_img_btn_top:active {
  background-color: rgba(100, 100, 100, 0.1) !important;
}
.webix_el_box .webix_img_btn_abs:active + input {
  background: #4d97ff;
}
/*.webix_toolbar .webix_img_btn:active, .webix_toolbar .webix_img_btn_top:active{
	background-color: rgba(255,255,255,0.1) !important;
};*/
.webix_el_box .webixtype_form {
  color: #ffffff;
  text-shadow: 0 1px #ffffff;
  background: #006bff;
  text-shadow: none !important;
  color: #ffffff !important;
  border: 1px solid #006bff;
  font-size: 15px !important;
}
.webix_el_box .webixtype_form:active {
  background: #1477ff;
}
.webixtype_base:active,
.webix_inp_counter_next:active,
.webix_inp_counter_prev:active {
  background: #4794ff;
}
.segmentActive {
  /*background: @buttonColor;
	border: 1px solid @buttonColor;
	text-shadow: none !important;
	color: @buttonFontColor !important;*/
  border: 1px solid #fea223 !important;
}
.webix_all_segments .webix_segment_0,
.webix_all_segments .webix_segment_1,
.webix_all_segments .webix_segment_N {
  border: none;
  color: #ffffff;
  font-size: 15px;
  border: 1px solid #3389ff !important;
}
.webix_all_segments .webix_segment_1,
.webix_all_segments .webix_segment_N {
  margin-left: 1px;
}
.webix_el_toggle {
  /*.webix_pressed .webix_img_btn, .webix_pressed .webix_img_btn_top{
		background-color: rgba(0,0,0,0.06);
	}
	.webix_el_box.webix_pressed > input{
		border-color: transparent;
		background: lighten(@buttonColor, 20%);//rgba(0,0,0,0.06) ;
		box-shadow: inset 0px 1px 2px rgba(0,0,0,0.3);
	}*/
}
.webix_cal_day {
  border-radius: 0px;
}
.webix_cal_day {
  border-radius: 0px;
}
.webix_cal_body .webix_cal_today {
  background: #f1f1f1;
}
.webix_progress_top .webix_progress_state,
.webix_progress_bottom .webix_progress_state {
  background-color: #3389ff;
  background-image: linear-gradient(135deg, rgba(255, 255, 255, 0.1) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.1) 50%, rgba(255, 255, 255, 0.1) 75%, transparent 75%, transparent);
}
.webix_progress_top .webix_progress_state {
  background-size: 10px 10px;
}
.webix_progress_bottom .webix_progress_state {
  background-size: 14px 14px;
}
.webix_skin_mark {
  height: 160px;
}
/*predefined styles for text lables inside a item*/
.webix_strong {
  font-weight: bold;
  white-space: nowrap;
}
.webix_light {
  color: #a2a2a2;
}
/*debug message styles*/
.webix_debug div {
  border: 1px solid orange;
  background-color: #FF9;
  color: #000;
}
.webix_debug {
  background-color: #ff9;
  border: 1px solid #ff9;
}
/*contr-styles for bootstrap*/
.webix_view,
.webix_input_icon {
  box-sizing: content-box;
}
.webix_view.webix_el_label {
  box-sizing: border-box;
}
.webix_inp_label,
.webix_inp_top_label,
.webix_label_right {
  margin-bottom: 0px;
}
.webix_view table {
  border-collapse: initial;
}
